@@ -13,6 +13,16 @@
 #import "UKCrashReporter.h"
 #import "UKSystemInfo.h"
 
+@interface UKCrashReporterWindow: NSWindow
+@end
+
+@implementation UKCrashReporterWindow
+
+- (void)closeCurrentSession:(id)sender {
+    [self performClose:sender];
+}
+
+@end
 
 NSString*    UKCrashReporterFindTenFiveCrashReportPath( NSString* appName, NSArray *folders );
 
@@ -117,11 +127,24 @@ void    UKCrashReporterCheckForCrash(void)
                 NSString*            numCPUsString = (numCores == 1) ? @"" : [NSString stringWithFormat: @"%dx ",numCores];
                 
                 // Create a string containing Mac and CPU info, crash log and prefs:
-                currentReport = [NSString stringWithFormat:
-                                    @"Model: %@\nCPU Speed: %@%.2f GHz\n%@\n",
-                                    UKMachineName(), numCPUsString, ((float)UKClockSpeed()) / 1000.0f,
-                                    currentReport];
-                
+                if (@available(macOS 12.0, *)) {
+                    NSString *shortVersionString = [[[NSBundle mainBundle] infoDictionary] objectForKey:@"CFBundleShortVersionString"];
+                    NSString *version = [[[NSBundle mainBundle] infoDictionary] objectForKey:@"CFBundleVersion"];
+                    currentReport = [NSString stringWithFormat:
+                                     @"Version: %@ (%@)\n"
+                                     @"Model: %@\n"
+                                     @"CPU Speed: %@%.2f GHz\n"
+                                     @"%@\n",
+                                     shortVersionString, version,
+                                     UKMachineName(),
+                                     numCPUsString, ((float)UKClockSpeed()) / 1000.0f,
+                                     currentReport];
+                } else {
+                    currentReport = [NSString stringWithFormat:
+                                        @"Model: %@\nCPU Speed: %@%.2f GHz\n%@\n",
+                                        UKMachineName(), numCPUsString, ((float)UKClockSpeed()) / 1000.0f,
+                                        currentReport];
+                }
                 // Now show a crash reporter window so the user can edit the info to send:
                 [[UKCrashReporter alloc] initWithLogString: currentReport];
             }
@@ -136,8 +159,15 @@ void    UKCrashReporterCheckForCrash(void)
 NSString* UKCrashReporterFindTenFiveCrashReportPath(NSString* appName, NSArray *folders)
 {
     NSString* currName = nil;
-    NSString* crashLogPrefix = [NSString stringWithFormat:@"%@_",appName];
-    NSString* crashLogSuffix = @".crash";
+    NSString* crashLogPrefix;
+    NSString* crashLogSuffix;
+    if (@available(macOS 12.0, *)) {
+        crashLogPrefix = [NSString stringWithFormat:@"%@-",appName];
+        crashLogSuffix = @".ips";
+    } else {
+        crashLogPrefix = [NSString stringWithFormat:@"%@_",appName];
+        crashLogSuffix = @".crash";
+    }
     NSString* foundName = nil;
     NSDate* foundDate = nil;
     NSString* foundFolder = nil;
@@ -174,7 +204,9 @@ NSString* UKCrashReporterFindTenFiveCrashReportPath(NSString* appName, NSArray *
 NSString*    gCrashLogString = nil;
 
 
-@implementation UKCrashReporter
+@implementation UKCrashReporter {
+    NSURLSessionDataTask *_dataTask;
+}
 
 -(id)    initWithLogString: (NSString*)theLog
 {
@@ -200,12 +232,23 @@ NSString*    gCrashLogString = nil;
 
 -(void) dealloc
 {
-    [connection release];
-    connection = nil;
+    [_dataTask release];
+    _dataTask = nil;
     
     [super dealloc];
 }
 
+- (BOOL)europeanLocale {
+    if (@available(macOS 10.12, *)) {
+        NSString *cc = [[NSLocale currentLocale] countryCode];
+        NSArray *europeanCountryCodes = @[ @"BE", @"BG", @"CZ", @"DK", @"DE", @"EE", @"IE", @"EL", @"ES", @"FR",
+                                           @"HR", @"IT", @"CY", @"LV", @"LT", @"LU", @"HU", @"MT", @"NL", @"AT",
+                                           @"PL", @"PT", @"RO", @"SI", @"SK", @"FI", @"SE", @"UK" ];
+        return !cc || [europeanCountryCodes containsObject:cc];
+    } else {
+        return YES;
+    }
+}
 
 -(void)    awakeFromNib
 {
@@ -226,9 +269,15 @@ NSString*    gCrashLogString = nil;
         userMessage = [[[informationField string] mutableCopy] autorelease];
     else
         userMessage = [[NSLocalizedStringFromTable(@"FEEDBACK_MESSAGE_TEXT",@"UKCrashReporter",@"") mutableCopy] autorelease];
+
+    NSString *emailAddr = NSLocalizedStringFromTable(@"MISSING_EMAIL_ADDRESS",@"UKCrashReporter",@"");
+
+    if ([self europeanLocale]) {
+        emailAddr = NSLocalizedStringFromTable(@"MISSING_EMAIL_ADDRESS",@"UKCrashReporter",@"");
+    }
+
     [userMessage replaceOccurrencesOfString: @"%%LONGUSERNAME" withString: NSFullUserName()
                 options: 0 range: NSMakeRange(0, [userMessage length])];
-    NSString*        emailAddr = NSLocalizedStringFromTable(@"MISSING_EMAIL_ADDRESS",@"UKCrashReporter",@"");
     [userMessage replaceOccurrencesOfString: @"%%EMAILADDRESS" withString: emailAddr
                 options: 0 range: NSMakeRange(0, [userMessage length])];
     [informationField setString: userMessage];
@@ -274,10 +323,11 @@ NSString*    gCrashLogString = nil;
     NSData*                crashReport = [crashReportString dataUsingEncoding: NSUTF8StringEncoding];
     
     // Prepare a request:
-    NSMutableURLRequest *postRequest = [NSMutableURLRequest requestWithURL: [NSURL URLWithString: NSLocalizedStringFromTable( @"CRASH_REPORT_CGI_URL", @"UKCrashReporter", @"" )]];
+    NSURL *url = [NSURL URLWithString: NSLocalizedStringFromTable( @"CRASH_REPORT_CGI_URL", @"UKCrashReporter", @"" )];
+    NSMutableURLRequest *postRequest = [NSMutableURLRequest requestWithURL: url];
     NSString            *contentType = [NSString stringWithFormat:@"multipart/form-data; boundary=%@",boundary];
     NSString            *agent = @"UKCrashReporter";
-    
+
     // Add form trappings to crashReport:
     NSData*            header = [[NSString stringWithFormat:@"--%@\r\nContent-Disposition: form-data; name=\"crashlog\"\r\n\r\n", boundary] dataUsingEncoding:NSUTF8StringEncoding];
     NSMutableData*    formData = [[header mutableCopy] autorelease];
@@ -286,6 +336,7 @@ NSString*    gCrashLogString = nil;
     
     // setting the headers:
     [postRequest setHTTPMethod: @"POST"];
+    [postRequest setValue: url.host forHTTPHeaderField: @"Host"];
     [postRequest setValue: contentType forHTTPHeaderField: @"Content-Type"];
     [postRequest setValue: agent forHTTPHeaderField: @"User-Agent"];
     NSString *contentLength = [NSString stringWithFormat:@"%lu", (unsigned long)[formData length]];
@@ -297,8 +348,22 @@ NSString*    gCrashLogString = nil;
     [sendButton setEnabled: NO];
     [remindButton setEnabled: NO];
     [discardButton setEnabled: NO];
-    
-    connection = [[NSURLConnection connectionWithRequest: postRequest delegate: self] retain];
+
+    _dataTask = [[NSURLSession sharedSession] dataTaskWithRequest:postRequest completionHandler:^(NSData * _Nullable data, NSURLResponse * _Nullable response, NSError * _Nullable error) {
+        if (error) {
+            [self performSelectorOnMainThread: @selector(showFinishedMessage:) withObject: error waitUntilDone: NO];
+            return;
+        }
+        // Now that we successfully sent this crash, don't report it again:
+        if (!feedbackMode) {
+            [[NSUserDefaults standardUserDefaults] setFloat: [[NSDate date] timeIntervalSince1970] forKey:@"UKCrashReporterLastCrashReportDate"];
+            [[NSUserDefaults standardUserDefaults] synchronize];
+        }
+
+        [self performSelectorOnMainThread: @selector(showFinishedMessage:) withObject: nil waitUntilDone: NO];
+    }];
+    [_dataTask retain];
+    [_dataTask resume];
 }
 
 
@@ -343,30 +408,6 @@ NSString*    gCrashLogString = nil;
 }
 
 
--(void)    connectionDidFinishLoading:(NSURLConnection *)conn
-{
-    [connection release];
-    connection = nil;
-    
-    // Now that we successfully sent this crash, don't report it again:
-    if( !feedbackMode )
-    {
-        [[NSUserDefaults standardUserDefaults] setFloat: [[NSDate date] timeIntervalSince1970] forKey: @"UKCrashReporterLastCrashReportDate"];
-        [[NSUserDefaults standardUserDefaults] synchronize];
-    }
-    
-    [self performSelectorOnMainThread: @selector(showFinishedMessage:) withObject: nil waitUntilDone: NO];
-}
-
-
--(void)    connection:(NSURLConnection *)conn didFailWithError:(NSError *)error
-{
-    [connection release];
-    connection = nil;
-    
-    [self performSelectorOnMainThread: @selector(showFinishedMessage:) withObject: error waitUntilDone: NO];
-}
-
 @end
 
 
