@@ -128,7 +128,7 @@ static const double kFloatingPointTolerance = 0.00001;
                                                    regex:regex
                                             substitution:substitution];
     [iTermPasteHelper sanitizePasteEvent:event encoding:NSUTF8StringEncoding];
-    XCTAssert([expected isEqualToString:event.string]);
+    XCTAssertEqualObjects(expected, event.string);
 }
 
 - (void)testSanitizeIdentity {
@@ -224,6 +224,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     [self runTimer];
@@ -237,6 +238,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     [self runTimer];
@@ -249,11 +251,12 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:YES
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformConvertToSpaces
             spacesPerTab:4];
     [self runTimer];
     NSString *expected = @"\\ \\ \\ \\ ";
-    XCTAssert([_writeBuffer isEqualToString:expected]);
+    XCTAssertEqualObjects(_writeBuffer, expected);
 }
 
 - (void)testEscapeDoesNotEscapeCarriageReturn {
@@ -261,6 +264,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:YES
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformConvertToSpaces
             spacesPerTab:4];
     [self runTimer];
@@ -273,11 +277,12 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:YES
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformConvertToSpaces
             spacesPerTab:4];
     [self runTimer];
     NSString *expected = @"a\\ \\(\\ \\ \\ \\ \r\r“”‘’–—b";
-    XCTAssert([_writeBuffer isEqualToString:expected]);
+    XCTAssertEqualObjects(_writeBuffer, expected);
 }
 
 - (void)testDoNotEscapeNonAscii {
@@ -285,6 +290,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:YES
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformEscapeWithCtrlV
             spacesPerTab:0];
     [self runTimer];
@@ -297,6 +303,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:YES
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformEscapeWithCtrlV
             spacesPerTab:0];
     [self runTimer];
@@ -309,6 +316,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:YES
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformEscapeWithCtrlV
             spacesPerTab:0];
     [self runTimer];
@@ -317,13 +325,11 @@ static const double kFloatingPointTolerance = 0.00001;
 }
 
 - (void)testMultilineWarningWithOverride {
-    iTermFakeUserDefaults *fakeDefaults = [[[iTermFakeUserDefaults alloc] init] autorelease];
-    [fakeDefaults setFakeObject:@YES forKey:@"PromptForPasteWhenNotAtPrompt"];
-    [fakeDefaults setFakeObject:@YES forKey:@"PromptForPasteWhenNotAtPrompt"];
-    [iTermSelectorSwizzler swizzleSelector:@selector(standardUserDefaults)
-                                 fromClass:[NSUserDefaults class]
-                                 withBlock:^ id { return fakeDefaults; }
+    [iTermSelectorSwizzler swizzleSelector:@selector(promptForPasteWhenNotAtPrompt)
+                                 fromClass:[iTermAdvancedSettingsModel class]
+                                 withBlock:^ BOOL { return YES; }
                                   forBlock:^{
+                                      [iTermAdvancedSettingsModel loadAdvancedSettingsFromUserDefaults];
                                       [self doMultilineWarningTestWithOverride:YES];
                                   }];
 }
@@ -347,6 +353,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     XCTAssert(!warned);
@@ -367,6 +374,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     if (override) {
@@ -381,6 +389,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     if (override) {
@@ -395,6 +404,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     if (override) {
@@ -410,6 +420,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     [self runTimer];
@@ -427,13 +438,14 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     _shouldBracket = NO;
     [self runTimer];
     NSString *expected = [[@"\x1b[200~" stringByAppendingString:test] stringByAppendingString:@"\x1b[201~"];
     XCTAssert([_writeBuffer isEqualToString:expected]);
-    XCTAssert(fabs(_helper.duration - 0.01) < kFloatingPointTolerance);
+    XCTAssert(fabs(_helper.duration - 0.02) < kFloatingPointTolerance);
 }
 
 - (void)testDelegateChangesItsMindAboutBracketingWithQueue {
@@ -443,6 +455,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     _shouldBracket = NO;
@@ -452,6 +465,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
 
@@ -466,11 +480,12 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     [self runTimer];
     XCTAssert([_writeBuffer isEqualToString:test]);
-    XCTAssert(fabs(_helper.duration - 0.01) < kFloatingPointTolerance);
+    XCTAssert(fabs(_helper.duration - 0.02) < kFloatingPointTolerance);
 }
 
 - (void)testSlowTwoChunkPasteString {
@@ -479,6 +494,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:YES
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     [self runTimer];
@@ -492,6 +508,7 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     NSString *test2 = [@"2" stringRepeatedTimes:2000];
@@ -499,11 +516,12 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     [self runTimer];
     XCTAssert([_writeBuffer isEqualToString:[test1 stringByAppendingString:test2]]);
-    NSTimeInterval expectedDuration = 2 * 0.01;
+    NSTimeInterval expectedDuration = 4 * 0.01;
     XCTAssert(fabs(_helper.duration - expectedDuration) < kFloatingPointTolerance);
     XCTAssert([[[[PasteboardHistory sharedInstance] entries][0] mainValue] isEqualToString:test1]);
     XCTAssert([[[[PasteboardHistory sharedInstance] entries][1] mainValue] isEqualToString:test2]);
@@ -515,9 +533,10 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
-    [_helper enqueueEvent:[NSEvent keyEventWithType:NSKeyDown
+    [_helper enqueueEvent:[NSEvent keyEventWithType:NSEventTypeKeyDown
                                            location:NSZeroPoint
                                       modifierFlags:0
                                           timestamp:[NSDate timeIntervalSinceReferenceDate]
@@ -532,11 +551,12 @@ static const double kFloatingPointTolerance = 0.00001;
                   slowly:NO
         escapeShellChars:NO
                 isUpload:NO
+         allowBracketing:YES
             tabTransform:kTabTransformNone
             spacesPerTab:0];
     [self runTimer];
     XCTAssert([_writeBuffer isEqualToString:[[test1 stringByAppendingString:@"x"] stringByAppendingString:test2]]);
-    NSTimeInterval expectedDuration = 2 * 0.01;
+    NSTimeInterval expectedDuration = 4 * 0.01;
     XCTAssert(fabs(_helper.duration - expectedDuration) < kFloatingPointTolerance);
 }
 
@@ -574,9 +594,19 @@ static const double kFloatingPointTolerance = 0.00001;
     return NO;
 }
 
-- (void)pasteHelperPasteViewVisibilityDidChange { 
+- (void)pasteHelperPasteViewVisibilityDidChange {
 }
 
+- (iTermVariableScope *)pasteHelperScope {
+    return nil;
+}
+
+
+- (iTermStatusBarViewController *)pasteHelperStatusBarViewController {
+    return nil;
+}
+
+
 #pragma mark - iTermWarningHandler
 
 - (NSModalResponse)warningWouldShowAlert:(NSAlert *)alert identifier:(NSString *)identifier {
