@@ -286,7 +286,7 @@ iTermWindowType iTermThemedWindowType(iTermWindowType windowType) {
 }
 
 + (NSFont *)fontWithDesc:(NSString *)fontDesc {
-    return [fontDesc fontValue];
+    return [(fontDesc ?: @"") fontValue];
 }
 
 - (void)setBookmarks:(NSArray *)newBookmarksArray defaultGuid:(NSString *)guid {
@@ -588,10 +588,12 @@ iTermWindowType iTermThemedWindowType(iTermWindowType windowType) {
 + (NSString *)shellLauncherCommandWithCustomShell:(NSString *)customShell {
     NSString *sanitizedCustomShell = [self sanitizedCustomShell:customShell];
     NSString *customShellArg = sanitizedCustomShell ? [@" SHELL=" stringByAppendingString:sanitizedCustomShell] : @"";
+    NSString *shellLauncher = [[NSBundle bundleForClass:self.class] pathForAuxiliaryExecutable:@"ShellLauncher"];
+
     return [NSString stringWithFormat:@"/usr/bin/login -f%@pl %@ %@ --launch_shell%@",
             [self hushlogin] ? @"q" : @"",
             [NSUserName() stringWithBackslashEscapedShellCharactersIncludingNewlines:YES],
-            [[[NSBundle mainBundle] executablePath] stringWithBackslashEscapedShellCharactersIncludingNewlines:YES],
+            [shellLauncher stringWithBackslashEscapedShellCharactersIncludingNewlines:YES],
             customShellArg];
 }
 
