@@ -129,7 +129,7 @@ static const NSInteger kUnicodeVersion = 9;
         [self commonInit];
         if ([dictionary[kLineBufferVersionKey] intValue] != kLineBufferVersion) {
             [self autorelease];
-            return nil;
+            return [[LineBuffer alloc] init];
         }
         _mayHaveDoubleWidthCharacter = [dictionary[kLineBufferMayHaveDWCKey] boolValue];
         block_size = [dictionary[kLineBufferBlockSizeKey] intValue];
@@ -146,7 +146,7 @@ static const NSInteger kUnicodeVersion = 9;
             LineBlock *block = [LineBlock blockWithDictionary:blockDictionary];
             if (!block) {
                 [self autorelease];
-                return nil;
+                return [[LineBuffer alloc] init];
             }
             [_lineBlocks addBlock:block];
         }
@@ -553,6 +553,26 @@ static int RawNumLines(LineBuffer* buffer, int width) {
     return RawNumLines(self, width);
 }
 
+- (void)removeLastWrappedLines:(int)numberOfLinesToRemove
+                         width:(int)width {
+    // Invalidate the cache
+    num_wrapped_lines_width = -1;
+
+    int linesToRemoveRemaining = numberOfLinesToRemove;
+    while (linesToRemoveRemaining > 0 && _lineBlocks.count > 0) {
+        LineBlock *block = _lineBlocks.lastBlock;
+        const int numberOfLinesInBlock = [block getNumLinesWithWrapWidth:width];
+        if (numberOfLinesInBlock > linesToRemoveRemaining) {
+            // Keep part of block
+            [block removeLastWrappedLines:linesToRemoveRemaining width:width];
+            return;
+        }
+        // Remove the whole block and try again.
+        [_lineBlocks removeLastBlock];
+        linesToRemoveRemaining -= numberOfLinesInBlock;
+    }
+}
+
 - (BOOL)popAndCopyLastLineInto:(screen_char_t*)ptr
                          width:(int)width
              includesEndOfLine:(int*)includesEndOfLine
@@ -674,6 +694,7 @@ NS_INLINE int TotalNumberOfRawLines(LineBuffer *self) {
                    options:(FindOptions)options
                       mode:(iTermFindMode)mode
                withContext:(FindContext*)context {
+    DLog(@"Prepare to search for %@", substring);
     context.substring = substring;
     context.options = options;
     if (options & FindOptBackwards) {
@@ -891,12 +912,6 @@ NS_INLINE int TotalNumberOfRawLines(LineBuffer *self) {
                          withWidth:width
                            yOffset:&yOffset
                            extends:&extends];
-    if (pos == 0 && yOffset == 1) {
-        // getPositionOfLine:… will set yOffset to 1 when returning the first cell of a raw line to
-        // disambiguate the position. That's the right thing to do except for the very first cell
-        // in a block, where the position is unambiguous.
-        yOffset = 0;
-    }
     if (pos < 0) {
         DLog(@"failed to get position of line %@", @(line));
         return nil;
@@ -1255,11 +1270,6 @@ NS_INLINE int TotalNumberOfRawLines(LineBuffer *self) {
 - (void)beginResizing {
     assert(!_lineBlocks.resizing);
     _lineBlocks.resizing = YES;
-
-    // Just a sanity check, not a real limitation.
-    dispatch_async(dispatch_get_main_queue(), ^{
-        assert(!_lineBlocks.resizing);
-    });
 }
 
 - (void)endResizing {
