@@ -11,7 +11,8 @@
 
 @interface iTermMetalClipView : NSClipView
 
-@property (nonatomic, weak) MTKView *metalView NS_AVAILABLE_MAC(10_11);
+@property (nonatomic, weak) MTKView *metalView;
+@property (nonatomic, weak) NSView *legacyView;
 @property (nonatomic) BOOL useMetal;
 
 - (void)performBlockWithoutShowingOverlayScrollers:(void (^ NS_NOESCAPE)(void))block;
