@@ -29,10 +29,12 @@
 #import "iTermAdvancedSettingsModel.h"
 #import "iTermMalloc.h"
 #import "iTermOrderedDictionary.h"
+#import "iTermPreferences.h"
 #import "iTermSwiftyStringParser.h"
 #import "iTermTuple.h"
 #import "iTermVariableScope.h"
 #import "NSArray+iTerm.h"
+#import "NSAttributedString+PSM.h"
 #import "NSData+iTerm.h"
 #import "NSLocale+iTerm.h"
 #import "NSMutableAttributedString+iTerm.h"
@@ -354,7 +356,7 @@
         if (!inSingleQuotes && !inDoubleQuotes && isWhitespace) {
             if (!isFirstCharacterOfWord) {
                 if (!firstCharacterOfThisWordWasQuoted) {
-                    [result addObject:[currentValue stringByExpandingTildeInPath]];
+                    [result addObject:[currentValue stringByExpandingTildeInPathPreservingSlash]];
                 } else {
                     [result addObject:currentValue];
                 }
@@ -376,6 +378,20 @@
     return result;
 }
 
+// For unknown reasons stringByExpandingTildeInPath removes terminal slashes. This method puts them
+// back. That is useful for completion suggestions.
+// ~                   -> /Users/example
+// ~/                  -> /Users/example/
+// /Users/example/foo  -> /Users/example/foo
+// /Users/example/foo/ -> /Users/example/foo/
+- (NSString *)stringByExpandingTildeInPathPreservingSlash {
+    NSString *candidate = [self stringByExpandingTildeInPath];
+    if ([self hasSuffix:@"/"] && ![candidate hasSuffix:@"/"]) {
+        return [candidate stringByAppendingString:@"/"];
+    }
+    return candidate;
+}
+
 - (NSString *)stringByReplacingBackreference:(int)n withString:(NSString *)s
 {
     return [self stringByReplacingEscapedChar:'0' + n withString:s];
@@ -395,8 +411,7 @@ static int fromhex(unichar c) {
     return c - 'A' + 10;
 }
 
-- (NSData *)dataFromHexValues
-{
+- (NSData *)dataFromHexValues {
     NSMutableData *data = [NSMutableData data];
     int length = self.length;  // Convert to signed so length-1 is safe below.
     for (int i = 0; i < length - 1; i+=2) {
@@ -408,6 +423,22 @@ static int fromhex(unichar c) {
     return data;
 }
 
+- (NSData *)dataFromWhitespaceDelimitedHexValues {
+    if (![self isMatchedByRegex:@"^[0-9A-Fa-f\\s]+$"]) {
+        return nil;
+    }
+    NSArray<NSString *> *parts = [self componentsSeparatedByCharactersInSet:[NSCharacterSet whitespaceAndNewlineCharacterSet]];
+    NSMutableData *result = [NSMutableData data];
+    for (NSString *string in parts) {
+        if (string.length % 2 != 0) {
+            return nil;
+        }
+        NSData *subdata = [string dataFromHexValues];
+        [result appendData:subdata];
+    }
+    return result;
+}
+
 - (NSString *)stringByReplacingEscapedHexValuesWithChars
 {
     NSMutableArray *ranges = [NSMutableArray array];
@@ -473,6 +504,35 @@ static int fromhex(unichar c) {
     return newString;
 }
 
+- (NSString *)stringByReplacingCommonlyEscapedCharactersWithControls {
+    NSString *p = [self stringByReplacingEscapedChar:'a' withString:@"\x07"];
+    p = [p stringByReplacingEscapedChar:'b' withString:@"\x08"];
+    p = [p stringByReplacingEscapedChar:'e' withString:@"\x1b"];
+    p = [p stringByReplacingEscapedChar:'n' withString:@"\n"];
+    p = [p stringByReplacingEscapedChar:'r' withString:@"\r"];
+    p = [p stringByReplacingEscapedChar:'t' withString:@"\t"];
+    p = [p stringByReplacingEscapedChar:'\\' withString:@"\\"];
+    p = [p stringByReplacingEscapedHexValuesWithChars];
+    return p;
+}
+
+- (NSString *)stringByEscapingControlCharactersAndBackslash {
+    NSString *result = [self stringByReplacingOccurrencesOfString:@"\\" withString:@"\\\\"];
+    for (int i = 0; i < 32; i++) {
+        NSString *replacement = [NSString stringWithFormat:@"\\x%04x", i];
+        if (i == '\n') {
+            replacement = @"\\n";
+        } else if (i == '\r') {
+            replacement = @"\\r";
+        } else if (i == '\t') {
+            replacement = @"\\t";
+        }
+        result = [result stringByReplacingOccurrencesOfString:[NSString stringWithLongCharacter:i]
+                                                   withString:replacement];
+    }
+    return result;
+}
+
 // foo"bar -> foo\"bar
 // foo\bar -> foo\\bar
 // foo\"bar -> foo\\\"bar
@@ -691,6 +751,11 @@ int decode_utf8_char(const unsigned char *datap,
     return [self substringFromIndex:i];
 }
 
+- (NSString *)base64EncodedWithEncoding:(NSStringEncoding)encoding {
+    NSData *data = [self dataUsingEncoding:encoding];
+    return [data base64EncodedStringWithOptions:0];
+}
+
 - (NSString *)stringByBase64DecodingStringWithEncoding:(NSStringEncoding)encoding {
     return [[NSString alloc] initWithData:[NSData dataWithBase64EncodedString:self]
                                  encoding:encoding];
@@ -895,6 +960,23 @@ int decode_utf8_char(const unsigned char *datap,
 
     DLog(@"Looking for font with string rep %@", self);
     NSString *fontName = [NSString stringWithFormat:@"%s", utf8FontName];
+    if (@available(macOS 12, *)) {
+        if ([fontName hasPrefix:@"."] && ![fontName hasPrefix:@".AppleSystemUIFont"]) {
+            // Well this is terrible
+            // Starting in, I guess, Ventura you can't round-trip font names for some mystery fonts.
+            // Somehow users have a font name of .SFNS-Regular in their prefs. This came from maybe
+            // an older OS version? Who the hell knows.
+            // Anyway when you try to create it now it gives you motherfucking times roman out of pure
+            // unadulterated spite.
+            // I reversed coretext and found that it fucks you for not names that start with a . except
+            // .AppleSystemUIFont. I guess I have to reverse this code every new OS version?
+            // 🖕to you too, CoreText.
+            // This will probably break something but fucked if I know what.
+            // Issue 10625
+            DLog(@"Translate font %@ to system font", fontName);
+            return [NSFont systemFontOfSize:fontSize];
+        }
+    }
     aFont = [NSFont fontWithName:fontName size:fontSize];
     if (aFont == nil) {
         DLog(@"Failed to look up font named %@. Falling back to to user font", fontName);
@@ -1329,10 +1411,12 @@ static TECObjectRef CreateTECConverterForUTF8Variants(TextEncodingVariant varian
         range = [self rangeOfString:@"$$" options:NSLiteralSearch range:rangeToSearch];
         if (start < 0) {
             start = range.location;
+        } else if (range.location == NSNotFound) {
+            break;
         } else {
             NSRange capture = NSMakeRange(start, NSMaxRange(range) - start);
             NSString *string = [self substringWithRange:capture];
-            if (string.length > 4) {  // length of 4 implies $$$$, which should be interpreted as $$
+            if (string.length >= 4) {  // length of 4 implies $$$$, which should be interpreted as $$
                 [set addObject:string];
             }
             start = -1;
@@ -1561,6 +1645,10 @@ static TECObjectRef CreateTECConverterForUTF8Variants(TextEncodingVariant varian
     return hash;
 }
 
+- (NSData *)hashWithSHA256 {
+    return [[self dataUsingEncoding:NSUTF8StringEncoding] it_sha256];
+}
+
 - (UTF32Char)firstCharacter {
     if (self.length == 0) {
         return 0;
@@ -1644,6 +1732,26 @@ static TECObjectRef CreateTECConverterForUTF8Variants(TextEncodingVariant varian
     return range.location == NSNotFound;
 }
 
+- (BOOL)isNonnegativeFractionalNumber {
+    NSArray<NSString *> *parts = [self componentsSeparatedByString:@"."];
+    if (parts.count == 0 || parts.count > 2) {
+        return NO;
+    }
+    if (parts.count == 1) {
+        // "123"
+        return [parts.firstObject isNumeric];
+    }
+    if (parts.count == 2) {
+        if (parts[0].length == 0) {
+            // ".1"
+            return [parts[1] isNumeric];
+        }
+        // "1.2"
+        return [parts[0] isNumeric] && [parts[1] isNumeric];
+    }
+    return NO;
+}
+
 - (BOOL)startsWithDigit {
     if (![self length]) {
         return NO;
@@ -1724,7 +1832,7 @@ static TECObjectRef CreateTECConverterForUTF8Variants(TextEncodingVariant varian
         size.height += frameSize.height;
     }
 
-    return NSMakeRect(0, 0, size.width, size.height);
+    return NSMakeRect(0, 0, ceil(size.width), ceil(size.height));
 }
 
 - (void)it_drawInRect:(CGRect)rect attributes:(NSDictionary *)attributes {
@@ -1804,8 +1912,8 @@ static TECObjectRef CreateTECConverterForUTF8Variants(TextEncodingVariant varian
         froms = [[NSMutableArray alloc] init];
         tos = [[NSMutableArray alloc] init];
         for (int i = 0; i < numberOfControlCharacters; i++) {
-            char utf8[2] = { i, 0 };
-            NSString *from = [NSString stringWithUTF8String:utf8];
+            unichar c = i;
+            NSString *from = [NSString stringWithCharacters:&c length:1];
             NSString *to = [NSString stringWithFormat:@"\\u%04x", i];
             [froms addObject:from];
             [tos addObject:to];
@@ -2108,6 +2216,14 @@ static TECObjectRef CreateTECConverterForUTF8Variants(TextEncodingVariant varian
     return prefixRange.location == 0;
 }
 
+- (NSString *)removingHTMLFromTabTitleIfNeeded {
+    if (![iTermPreferences boolForKey:kPreferenceKeyHTMLTabTitles]) {
+        return self;
+    }
+    NSAttributedString *attributedString = [NSAttributedString newAttributedStringWithHTML:self attributes:@{}];
+    return attributedString.string;
+}
+
 @end
 
 @implementation NSMutableString (iTerm)
