@@ -8,6 +8,9 @@
 
 #import "NSWorkspace+iTerm.h"
 
+#import "DebugLogging.h"
+#import "iTermMalloc.h"
+
 @implementation NSWorkspace (iTerm)
 
 - (NSString *)temporaryFileNameWithPrefix:(NSString *)prefix suffix:(NSString *)suffix {
@@ -16,11 +19,12 @@
         [NSTemporaryDirectory() stringByAppendingPathComponent:template];
     const char *tempFileTemplateCString =
         [tempFileTemplate fileSystemRepresentation];
-    char *tempFileNameCString = (char *)malloc(strlen(tempFileTemplateCString) + 1);
+    char *tempFileNameCString = (char *)iTermMalloc(strlen(tempFileTemplateCString) + 1);
     strcpy(tempFileNameCString, tempFileTemplateCString);
     int fileDescriptor = mkstemps(tempFileNameCString, suffix.length);
 
     if (fileDescriptor == -1) {
+        XLog(@"mkstemps failed with template %s: %s", tempFileNameCString, strerror(errno));
         free(tempFileNameCString);
         return nil;
     }
