@@ -263,6 +263,9 @@ backgroundColor:(NSColor *)backgroundColor;
 - (id<iTermSwipeHandler>)sessionSwipeHandler;
 - (BOOL)sessionIsInSelectedTab:(PTYSession *)session;
 - (void)sessionDisableFocusFollowsMouseAtCurrentLocation;
+- (void)sessionDidResize:(PTYSession *)session;
+- (BOOL)sessionPasswordManagerWindowIsOpen;
+
 @end
 
 @class SessionView;
@@ -598,8 +601,14 @@ backgroundColor:(NSColor *)backgroundColor;
 - (BOOL)setScreenSize:(NSRect)aRect parent:(id<WindowControllerInterface>)parent;
 
 // triggers
+- (void)setAllTriggersEnabled:(BOOL)enabled;
 - (void)clearTriggerLine;
+- (BOOL)anyTriggerCanBeEnabled;
+- (BOOL)anyTriggerCanBeDisabled;
 - (void)appendStringToTriggerLine:(NSString *)s;
+// (regex, enabled)
+- (NSArray<iTermTuple<NSString *, NSNumber *> *> *)triggerTuples;
+- (void)toggleTriggerEnabledAtIndex:(NSInteger)index;
 
 + (void)drawArrangementPreview:(NSDictionary *)arrangement frame:(NSRect)frame;
 - (void)setSizeFromArrangement:(NSDictionary*)arrangement;
@@ -774,6 +783,8 @@ backgroundColor:(NSColor *)backgroundColor;
 - (void)launchSilentCoprocessWithCommand:(NSString *)command;
 
 - (void)setFocused:(BOOL)focused;
+- (void)performBlockWithoutFocusReporting:(void (^NS_NOESCAPE)(void))block;
+- (void)incrementDisableFocusReporting:(NSInteger)delta;
 - (BOOL)wantsContentChangedNotification;
 
 // The dcsID identifies the parser associated with this session. Parsers run in
@@ -823,6 +834,7 @@ backgroundColor:(NSColor *)backgroundColor;
 - (void)toggleTmuxZoom;
 - (void)forceTmuxDetach;
 - (void)tmuxDidDisconnect;
+- (void)tmuxWindowTitleDidChange;
 
 // This is to work around a macOS bug where setNeedsDisplay: on the root view controller does not
 // cause the TextViewWrapper to be redrawn in its entirety.
