@@ -11,6 +11,7 @@
 #import "iTermSemanticHistoryController.h"
 #import "iTermTextDrawingHelper.h"
 #import "LineBuffer.h"
+#import "NSEvent+iTerm.h"
 #import "PasteEvent.h"
 #import "PointerController.h"
 #import "PreferencePanel.h"
@@ -52,6 +53,14 @@ typedef NS_ENUM(NSInteger, PTYCharType) {
     CHARTYPE_OTHER,       // Symbols, etc. Anything that doesn't fall into the other categories.
 };
 
+typedef NS_ENUM(NSUInteger, iTermSendTextEscaping) {
+    iTermSendTextEscapingNone = 0,  // Send literal text
+    iTermSendTextEscapingCompatibility = 1,  // Escape only n, e, a, and t. Used in many places prior to 3.4.5beta2.
+    iTermSendTextEscapingCommon = 2,  // Use stringByReplacingCommonlyEscapedCharactersWithControls
+    iTermSendTextEscapingVim = 3,  // Use stringByExpandingVimSpecialCharacters;
+    iTermSendTextEscapingVimAndCompatibility = 4,  // Use stringByExpandingVimSpecialCharacters FOLLOWED BY n, e, a, t. Bugward compatibility.
+};
+
 @protocol PTYTextViewDelegate <NSObject, iTermBadgeLabelDelegate>
 
 @property (nonatomic, readonly) NSEdgeInsets textViewEdgeInsets;
@@ -63,12 +72,14 @@ typedef NS_ENUM(NSInteger, PTYCharType) {
 - (void)queueKeyDown:(NSEvent *)event;
 - (void)keyDown:(NSEvent *)event;
 - (void)keyUp:(NSEvent *)event;
+- (void)textViewhandleSpecialKeyDown:(NSEvent *)event;
 - (BOOL)hasActionableKeyMappingForEvent:(NSEvent *)event;
 - (iTermOptionKeyBehavior)optionKey;
 - (iTermOptionKeyBehavior)rightOptionKey;
 // Contextual menu
 - (void)menuForEvent:(NSEvent *)theEvent menu:(NSMenu *)theMenu;
 - (void)pasteString:(NSString *)aString;
+- (void)pasteStringWithoutBracketing:(NSString *)theString;
 - (void)paste:(id)sender;
 - (void)pasteOptions:(id)sender;
 - (void)textViewFontDidChange;
@@ -79,7 +90,10 @@ typedef NS_ENUM(NSInteger, PTYCharType) {
 - (BOOL)textViewHasBackgroundImage;
 - (void)sendEscapeSequence:(NSString *)text;
 - (void)sendHexCode:(NSString *)codes;
-- (void)sendText:(NSString *)text;
+- (void)sendText:(NSString *)text
+useCompatibilityEscaping:(BOOL)useCompatibilityEscaping
+compatibilityEscaping:(iTermSendTextEscaping)compatibilityEscaping
+preferredEscaping:(iTermSendTextEscaping)preferredEscaping;
 - (void)sendTextSlowly:(NSString *)text;
 - (void)textViewSelectionDidChangeToTruncatedString:(NSString *)maybeSelection;
 - (void)launchCoprocessWithCommand:(NSString *)command;
@@ -165,6 +179,7 @@ typedef NS_ENUM(NSInteger, PTYCharType) {
 - (BOOL)isRestartable;
 - (void)textViewToggleAnnotations;
 - (BOOL)textViewShouldAcceptKeyDownEvent:(NSEvent *)event;
+- (void)textViewDidReceiveFlagsChangedEvent:(NSEvent *)event;
 - (iTermExpect *)textViewExpect;
 
 // We guess the user is trying to send arrow keys with the scroll wheel in alt screen.
@@ -221,6 +236,12 @@ typedef NS_ENUM(NSInteger, PTYCharType) {
                           forMenuItem:(NSString *)title;
 - (void)textViewApplyAction:(iTermAction *)action;
 - (void)textViewAddTrigger:(NSString *)text;
+- (void)textViewEditTriggers;
+- (void)textViewToggleEnableTriggersInInteractiveApps;
+- (BOOL)textViewTriggersAreEnabledInInteractiveApps;
+- (iTermTimestampsMode)textviewTimestampsMode;
+- (void)textviewToggleTimestampsMode;
+
 @end
 
 @interface iTermHighlightedRow : NSObject
@@ -234,6 +255,7 @@ typedef NS_ENUM(NSInteger, PTYCharType) {
   iTermFocusFollowsMouseFocusReceiver,
   iTermIndicatorsHelperDelegate,
   iTermSemanticHistoryControllerDelegate,
+  iTermSpecialHandlerForAPIKeyDownNotifications,
   iTermTextDrawingHelperDelegate,
   NSDraggingDestination,
   NSTextInputClient,
@@ -352,7 +374,8 @@ typedef NS_ENUM(NSInteger, PTYCharType) {
 typedef void (^PTYTextViewDrawingHookBlock)(iTermTextDrawingHelper *);
 @property(nonatomic, copy) PTYTextViewDrawingHookBlock drawingHook;
 
-@property(nonatomic, assign) BOOL showTimestamps;
+@property(nonatomic, readonly) BOOL showTimestamps;
+@property(nonatomic, readonly) iTermTimestampsMode timestampsMode;
 
 @property(nonatomic, readonly) BOOL anyAnnotationsAreVisible;
 
@@ -438,6 +461,7 @@ typedef void (^PTYTextViewDrawingHookBlock)(iTermTextDrawingHelper *);
 
 // Copy with or without styles, as set by user defaults. Not for use when a copy item in the menu is invoked.
 - (void)copySelectionAccordingToUserPreferences;
+- (void)copyString:(NSString *)string;
 
 // Copy the current selection to the pasteboard.
 - (void)copy:(id)sender;
