@@ -47,6 +47,7 @@ extern const NSTimeInterval iTermWindowTitleChangeMinimumInterval;
 - (BOOL)anyFullScreen;
 - (void)windowWillShowInitial;
 - (void)toggleTraditionalFullScreenMode;
+- (BOOL)terminalWindowShouldHaveTitlebarSeparator NS_AVAILABLE_MAC(10_16);
 
 // Returns the tab a session belongs to.
 - (PTYTab *)tabForSession:(PTYSession *)session;
@@ -58,6 +59,8 @@ extern const NSTimeInterval iTermWindowTitleChangeMinimumInterval;
 - (id<PSMTabStyle>)terminalWindowTabStyle;
 - (NSColor *)terminalWindowDecorationControlColor;
 - (BOOL)terminalWindowUseMinimalStyle;
+// This is called only for the menu item window > move to (screen name)
+- (void)terminalWindowWillMoveToScreen:(NSScreen *)screen;
 
 typedef NS_ENUM(NSUInteger, PTYWindowTitleBarFlavor) {
     PTYWindowTitleBarFlavorDefault,
@@ -68,6 +71,8 @@ typedef NS_ENUM(NSUInteger, PTYWindowTitleBarFlavor) {
 - (PTYWindowTitleBarFlavor)ptyWindowTitleBarFlavor;
 
 - (BOOL)ptyWindowIsDraggable:(id<PTYWindow>)window;
+- (void)ptyWindowDidMakeKeyAndOrderFront:(id<PTYWindow>)window;
+- (BOOL)toggleFullScreenShouldUseLionFullScreen;
 @end
 
 // Common methods implemented by terminal windows of both kinds.
@@ -101,6 +106,7 @@ typedef NS_ENUM(NSUInteger, PTYWindowTitleBarFlavor) {
 // Returns the approximate fraction of this window that is occluded by other windows in this app.
 - (double)approximateFractionOccluded;
 - (void)it_setNeedsInvalidateShadow;
+- (void)setUpdatingDividerLayer:(BOOL)value;
 
 @end
 
