@@ -237,7 +237,7 @@ NSString *const kTmuxWindowOpenerWindowOptionStyleValueFullScreen = @"FullScreen
 - (NSDictionary *)dictForGetUserVars:(NSNumber *)wp {
     ++pendingRequests_;
     DLog(@"Increment pending requests to %d", pendingRequests_);
-    NSString *command = [NSString stringWithFormat:@"show-options -v -p -t %%%d @uservars",
+    NSString *command = [NSString stringWithFormat:@"show-options -q -v -p -t %%%d @uservars",
                          [wp intValue]];
     return [gateway_ dictionaryForCommand:command
                            responseTarget:self
@@ -382,12 +382,7 @@ static int OctalValue(const char *bytes) {
 }
 
 - (void)getUserVarsResponse:(NSString *)response pane:(NSNumber *)wp {
-    if (!response) {
-        [self didReceiveError];
-        return;
-    }
-
-    if (wp) {
+    if (response && wp) {
         [self.controller setEncodedUserVars:response forPane:wp.intValue];
     }
     [self requestDidComplete];
@@ -480,11 +475,13 @@ static int OctalValue(const char *bytes) {
     [self decorateParseTree:parseTree];
     DLog(@"Decorated parse tree: %@", parseTree);
     NSValue *windowPos = nil;
+    NSString *widStr = [@(windowIndex_) stringValue];
     if (tabToUpdate_) {
         DLog(@"Updating existing tab");
         [tabToUpdate_ setTmuxLayout:parseTree
                      tmuxController:controller_
                              zoomed:@NO];
+        [tabToUpdate_ setPerTabSettings:_perTabSettings[widStr]];
         if ([tabToUpdate_ updatedTmuxLayoutRequiresAdjustment]) {
             DLog(@"layout requires adjustment! fit the layout to windows");
             [controller_ fitLayoutToWindows];
@@ -528,6 +525,7 @@ static int OctalValue(const char *bytes) {
         } else {
             DLog(@"Not calling loadTmuxLayout");
         }
+        [[self.controller window:windowIndex_] setPerTabSettings:_perTabSettings[widStr]];
     }
     if (self.target) {
         [self.target performSelector:self.selector
