@@ -7,6 +7,7 @@
 //
 
 #import "VT100CSIParser.h"
+#import "iTermParser.h"
 
 // Functions to modify the packed command in CSIParam.cmd.
 static int32_t SetFinalByteInPackedCommand(int32_t command, unsigned char c) {
@@ -40,6 +41,7 @@ static int32_t SetPrefixByteInPackedCommand(int32_t command, unsigned char c) {
 // then NO is returned. If all is well, YES is returned and parsing can
 // continue. Non-canceling control characters are appended to |incidentals|
 static BOOL AdvanceAndEatControlChars(iTermParserContext *context,
+                                      BOOL support8BitControlCharacters,
                                       CVector *incidentals) {
     // First, advance if possible.
     iTermParserTryAdvance(context);
@@ -61,7 +63,7 @@ static BOOL AdvanceAndEatControlChars(iTermParserContext *context,
             case VT100CC_DC1:
             case VT100CC_DC3:
             case VT100CC_DEL:
-                CVectorAppend(incidentals, [VT100Token tokenForControlCharacter:c]);
+                CVectorAppend(incidentals, [VT100Token newTokenForControlCharacter:c]);
                 break;
 
             case VT100CC_CAN:
@@ -69,6 +71,17 @@ static BOOL AdvanceAndEatControlChars(iTermParserContext *context,
             case VT100CC_ESC:
                 return NO;
 
+            case VT100CC_C1_ST:
+            case VT100CC_C1_CSI:
+            case VT100CC_C1_SOS:
+            case VT100CC_C1_PM:
+            case VT100CC_C1_APC:
+            case VT100CC_C1_DCS:
+                if (support8BitControlCharacters) {
+                    return NO;
+                }
+                // fall through
+
             default:
                 if (c >= 0x20) {
                     return YES;
@@ -89,14 +102,23 @@ static void CSIParamInitialize(CSIParam *param) {
     }
 }
 
-static BOOL ParseCSIPrologue(iTermParserContext *context, CVector *incidentals) {
-    iTermParserConsumeOrDie(context, VT100CC_ESC);
-    assert(iTermParserCanAdvance(context));
-    assert(iTermParserPeek(context) == '[');
-    return AdvanceAndEatControlChars(context, incidentals);
+static BOOL ParseCSIPrologue(iTermParserContext *context, BOOL support8BitControlCharacters, CVector *incidentals) {
+    if (support8BitControlCharacters && iTermParserPeek(context) == VT100CC_C1_CSI) {
+        // Do nothing, will advance on next statement after the if.
+    } else {
+        iTermParserConsumeOrDie(context, VT100CC_ESC);
+        assert(iTermParserCanAdvance(context));
+        assert(iTermParserPeek(context) == '[');
+    }
+    return AdvanceAndEatControlChars(context,
+                                     support8BitControlCharacters,
+                                     incidentals);
 }
 
-static BOOL ParseCSIPrefix(iTermParserContext *context, CVector *incidentals, CSIParam *param) {
+static BOOL ParseCSIPrefix(iTermParserContext *context,
+                           BOOL support8BitControlCharacters,
+                           CVector *incidentals,
+                           CSIParam *param) {
     // Now we parse Parameter Bytes (ECMA-48, 5.4 - (b))
     //
     // CSI P...P I...I F
@@ -137,7 +159,7 @@ static BOOL ParseCSIPrefix(iTermParserContext *context, CVector *incidentals, CS
             case '>':
             case '?':
                 param->cmd = SetPrefixByteInPackedCommand(param->cmd, c);
-                if (!AdvanceAndEatControlChars(context, incidentals)) {
+                if (!AdvanceAndEatControlChars(context, support8BitControlCharacters, incidentals)) {
                     return NO;
                 }
                 break;
@@ -150,6 +172,7 @@ static BOOL ParseCSIPrefix(iTermParserContext *context, CVector *incidentals, CS
 }
 
 static BOOL ParseCSIParameters(iTermParserContext *context,
+                               BOOL support8BitControlCharacters,
                                CVector *incidentals,
                                CSIParam *param,
                                BOOL *unrecognized) {
@@ -177,13 +200,14 @@ static BOOL ParseCSIParameters(iTermParserContext *context,
                 while (iTermParserTryPeek(context, &c) && isdigit(c)) {
                     if (n > (INT_MAX - 10) / 10) {
                         *unrecognized = YES;
+                    } else {
+                        n = n * 10 + (c - '0');
                     }
-                    n = n * 10 + (c - '0');
-                    if (!AdvanceAndEatControlChars(context, incidentals)) {
+                    if (!AdvanceAndEatControlChars(context, support8BitControlCharacters, incidentals)) {
                         return NO;
                     }
                 }
-                
+
                 if (isSub && param->count > 0) {
                     // This implementation is not really well aligned with the spec. In ECMA-48
                     // section 5.4, the format of a CSI code is described. The parameter string,
@@ -191,29 +215,25 @@ static BOOL ParseCSIParameters(iTermParserContext *context,
                     // A parameter substring is a sequence of digits with colon separators.
                     // The data structure we use treats each parameter string up to the first
                     // colon (if any) as the parameter, and parts after the first colon as
-                    // sub-parameters. That doesn't really make sense if a paramater string
+                    // sub-parameters. That doesn't really make sense if a parameter string
                     // starts with a colon, which is allowed but not defined in the spec.
                     // Since that never should happen in practice, we'll just ignore a parameter
                     // string that starts with a colon.
                     const int paramNum = param->count - 1;
                     assert(paramNum >= 0 && paramNum < VT100CSIPARAM_MAX);
-                    int subParamNum = param->subCount[paramNum];
-                    if (subParamNum < VT100CSISUBPARAM_MAX) {
-                        param->sub[paramNum][subParamNum] = n;
-                        param->subCount[paramNum]++;
-                    }
+                    iTermParserAddCSISubparameter(param, paramNum, n);
                 } else if (param->count < VT100CSIPARAM_MAX) {
                     param->p[param->count] = n;
                     // increment the parameter count
                     param->count++;
                 }
-                
+
                 // set the numeric parameter flag
                 readNumericParameter = YES;
-                
+
                 break;
             }
-                
+
             case ';':
                 // If we got an implied (blank) parameter, increment the parameter count again
                 if (param->count < VT100CSIPARAM_MAX && readNumericParameter == NO) {
@@ -221,12 +241,12 @@ static BOOL ParseCSIParameters(iTermParserContext *context,
                 }
                 // reset the parameter flag
                 readNumericParameter = NO;
-                
-                if (!AdvanceAndEatControlChars(context, incidentals)) {
+                isSub = NO;
+                if (!AdvanceAndEatControlChars(context, support8BitControlCharacters, incidentals)) {
                     return NO;
                 }
                 break;
-                
+
             case ':':
                 // 2013/1/10 H. Saito
                 // TODO: Now colon separator(":") used in SGR sequence by few terminals
@@ -253,15 +273,15 @@ static BOOL ParseCSIParameters(iTermParserContext *context,
                 //
                 // In this usage, ":" are certainly treated as sub-parameter separators.
                 isSub = YES;
-                if (!AdvanceAndEatControlChars(context, incidentals)) {
+                if (!AdvanceAndEatControlChars(context, support8BitControlCharacters, incidentals)) {
                     return NO;
                 }
                 break;
-                
+
             default:
                 // '<', '=', '>', or '?'
                 *unrecognized = YES;
-                if (!AdvanceAndEatControlChars(context, incidentals)) {
+                if (!AdvanceAndEatControlChars(context, support8BitControlCharacters, incidentals)) {
                     return NO;
                 }
                 break;
@@ -272,6 +292,7 @@ static BOOL ParseCSIParameters(iTermParserContext *context,
 }
 
 static BOOL ParseCSIIntermediate(iTermParserContext *context,
+                                 BOOL support8BitControlCharacters,
                                  CVector *incidentals,
                                  CSIParam *param) {
     // Now we parse intermediate bytes (ECMA-48, 5.4 - (c))
@@ -283,14 +304,17 @@ static BOOL ParseCSIIntermediate(iTermParserContext *context,
     unsigned char c;
     while (iTermParserTryPeek(context, &c) && c >= 0x20 && c <= 0x2f) {
         param->cmd = SetIntermediateByteInPackedCommand(param->cmd, c);
-        if (!AdvanceAndEatControlChars(context, incidentals)) {
+        if (!AdvanceAndEatControlChars(context, support8BitControlCharacters, incidentals)) {
             return NO;
         }
     }
     return YES;
 }
 
-static BOOL ParseCSIGarbage(iTermParserContext *context, CVector *incidentals, BOOL *unrecognized) {
+static BOOL ParseCSIGarbage(iTermParserContext *context,
+                            BOOL support8BitControlCharacters,
+                            CVector *incidentals,
+                            BOOL *unrecognized) {
     // compatibility HACK:
     //
     // CSI P...P I...I (G...G) F
@@ -309,7 +333,7 @@ static BOOL ParseCSIGarbage(iTermParserContext *context, CVector *incidentals, B
                 // a character in the range [0x20,0x3f] occur after an 0x7f.
                 *unrecognized = YES;
             }
-            if (!AdvanceAndEatControlChars(context, incidentals)) {
+            if (!AdvanceAndEatControlChars(context, support8BitControlCharacters, incidentals)) {
                 return NO;
             }
         }
@@ -335,7 +359,10 @@ static void ParseCSIFinal(iTermParserContext *context, CSIParam *param, BOOL *un
     }
 }
 
-static void ParseCSISequence(iTermParserContext *context, CSIParam *param, CVector *incidentals) {
+static void ParseCSISequence(iTermParserContext *context,
+                             BOOL support8BitControlCharacters,
+                             CSIParam *param,
+                             CVector *incidentals) {
     // A CSI sequence consists of a prefix byte, zero or more parameters (optionally with sub-
     // parameters), zero or more intermediate bytes, and a final byte.
     //
@@ -368,11 +395,11 @@ static void ParseCSISequence(iTermParserContext *context, CSIParam *param, CVect
 
     CSIParamInitialize(param);
 
-    if (ParseCSIPrologue(context, incidentals) &&
-        ParseCSIPrefix(context, incidentals, param) &&
-        ParseCSIParameters(context, incidentals, param, &unrecognized) &&
-        ParseCSIIntermediate(context, incidentals, param) &&
-        ParseCSIGarbage(context, incidentals, &unrecognized)) {
+    if (ParseCSIPrologue(context, support8BitControlCharacters, incidentals) &&
+        ParseCSIPrefix(context, support8BitControlCharacters, incidentals, param) &&
+        ParseCSIParameters(context, support8BitControlCharacters, incidentals, param, &unrecognized) &&
+        ParseCSIIntermediate(context, support8BitControlCharacters, incidentals, param) &&
+        ParseCSIGarbage(context, support8BitControlCharacters, incidentals, &unrecognized)) {
         ParseCSIFinal(context, param, &unrecognized);
     } else {
         param->cmd = INVALID_CSI_CMD;
@@ -389,6 +416,14 @@ static void SetCSITypeAndDefaultParameters(CSIParam *param, VT100Token *result)
             result->type = VT100_WAIT;
             break;
 
+        case PACKED_CSI_COMMAND(0, '#', '|'):  // XTREPORTSGR
+            result->type = VT100CSI_XTREPORTSGR;
+            iTermParserSetCSIParameterIfDefault(param, 0, 1);
+            iTermParserSetCSIParameterIfDefault(param, 1, 1);
+            iTermParserSetCSIParameterIfDefault(param, 2, 1);
+            iTermParserSetCSIParameterIfDefault(param, 3, 1);
+            break;
+
         case 'D':       // Cursor Backward
             result->type = VT100CSI_CUB;
             iTermParserSetCSIParameterIfDefault(param, 0, 1);
@@ -430,6 +465,11 @@ static void SetCSITypeAndDefaultParameters(CSIParam *param, VT100Token *result)
             iTermParserSetCSIParameterIfDefault(param, 1, 1);
             break;
 
+        case 'I':
+            result->type = VT100CSI_CHT;
+            iTermParserSetCSIParameterIfDefault(param, 0, 1);
+            break;
+
         case 'c':
             result->type = VT100CSI_DA;
             iTermParserSetCSIParameterIfDefault(param, 0, 0);
@@ -504,10 +544,39 @@ static void SetCSITypeAndDefaultParameters(CSIParam *param, VT100Token *result)
             iTermParserSetCSIParameterIfDefault(param, 0, 0);
             break;
 
+        case PACKED_CSI_COMMAND('>', 0, 'q'):
+            result->type = VT100CSI_XDA;
+            iTermParserSetCSIParameterIfDefault(param, 0, 0);
+            break;
+
+        case PACKED_CSI_COMMAND('>', 0, 'u'):
+            iTermParserSetCSIParameterIfDefault(param, 0, 0);
+            result->type = VT100CSI_PUSH_KEY_REPORTING_MODE;
+            break;
+
+        case PACKED_CSI_COMMAND('<', 0, 'u'):
+            iTermParserSetCSIParameterIfDefault(param, 0, 0);
+            result->type = VT100CSI_POP_KEY_REPORTING_MODE;
+            break;
+
+        case PACKED_CSI_COMMAND('?', 0, 'u'):
+            result->type = VT100CSI_QUERY_KEY_REPORTING_MODE;
+            break;
+
         case PACKED_CSI_COMMAND(0, '!', 'p'):
             result->type = VT100CSI_DECSTR;
             break;
 
+        case PACKED_CSI_COMMAND('?', '$', 'p'):
+            result->type = VT100CSI_DECRQM_DEC;
+            iTermParserSetCSIParameterIfDefault(param, 0, 0);
+            break;
+
+        case PACKED_CSI_COMMAND(0, '$', 'p'):
+            result->type = VT100CSI_DECRQM_ANSI;
+            iTermParserSetCSIParameterIfDefault(param, 0, 0);
+            break;
+
         case PACKED_CSI_COMMAND(0, '*', 'y'):
             result->type = VT100CSI_DECRQCRA;
             iTermParserSetCSIParameterIfDefault(param, 2, 1);
@@ -639,17 +708,18 @@ static void SetCSITypeAndDefaultParameters(CSIParam *param, VT100Token *result)
         default:
             result->type = VT100_NOTSUPPORT;
             break;
-            
+
     }
 }
 
 + (void)decodeFromContext:(iTermParserContext *)context
+support8BitControlCharacters:(BOOL)support8BitControlCharacters
               incidentals:(CVector *)incidentals
                     token:(VT100Token *)result {
     CSIParam *param = result.csi;
     iTermParserContext savedContext = *context;
 
-    ParseCSISequence(context, param, incidentals);
+    ParseCSISequence(context, support8BitControlCharacters, param, incidentals);
     SetCSITypeAndDefaultParameters(param, result);
     if (result->type == VT100_WAIT) {
         *context = savedContext;
