@@ -9,8 +9,11 @@
 #import "VT100Grid.h"
 
 #import "DebugLogging.h"
+#import "iTermEncoderAdapter.h"
 #import "LineBuffer.h"
+#import "NSArray+iTerm.h"
 #import "NSDictionary+iTerm.h"
+#import "NSObject+iTerm.h"
 #import "VT100GridTypes.h"
 #import "VT100LineInfo.h"
 #import "VT100Terminal.h"
@@ -28,8 +31,8 @@ static NSString *const kGridSizeKey = @"Size";
 @implementation VT100Grid {
     VT100GridSize size_;
     int screenTop_;  // Index into lines_ and dirty_ of first line visible in the grid.
-    NSMutableArray *lines_;  // Array of NSMutableData. Each data has size_.width+1 screen_char_t's.
-    NSMutableArray *lineInfos_;  // Array of VT100LineInfo.
+    NSMutableArray<NSMutableData *> *lines_;  // Array of NSMutableData. Each data has size_.width+1 screen_char_t's.
+    NSMutableArray<VT100LineInfo *> *lineInfos_;  // Array of VT100LineInfo.
     id<VT100GridDelegate> delegate_;
     VT100GridCoord cursor_;
     VT100GridRange scrollRegionRows_;
@@ -63,6 +66,44 @@ static NSString *const kGridSizeKey = @"Size";
     return self;
 }
 
+- (instancetype)initWithDictionary:(NSDictionary *)dictionary
+                          delegate:(id<VT100GridDelegate>)delegate {
+    self = [super init];
+    if (self) {
+        delegate_ = delegate;
+        NSArray<NSString *> *requiredKeys = @[ @"size", @"lines", @"cursor" ];
+        for (NSString *requiredKey in requiredKeys) {
+            if (!dictionary[requiredKey]) {
+                [self release];
+                return nil;
+            }
+        }
+        [self setSize:[NSDictionary castFrom:dictionary[@"size"]].gridSize];
+        assert(size_.width > 0 && size_.height > 0);
+        lines_ = [[NSArray castFrom:dictionary[@"lines"]] mutableCopy];
+        [[NSArray castFrom:dictionary[@"timestamps"]] enumerateObjectsUsingBlock:^(NSNumber *timestamp,
+                                                                                   NSUInteger idx,
+                                                                                   BOOL * _Nonnull stop) {
+            if (idx >= lineInfos_.count) {
+                DLog(@"Too many lineInfos");
+                *stop = YES;
+                return;
+            }
+            lineInfos_[idx].timestamp = timestamp.doubleValue;
+        }];
+        cursor_ = [NSDictionary castFrom:dictionary[@"cursor"]].gridCoord;
+        scrollRegionRows_ = [NSDictionary castFrom:dictionary[@"scrollRegionRows"]].gridRange;
+        scrollRegionCols_ = [NSDictionary castFrom:dictionary[@"scrollRegionCols"]].gridRange;
+        useScrollRegionCols_ = [NSNumber castFrom:dictionary[@"useScrollRegionCols"]].boolValue;
+        NSData *data = [NSData castFrom:dictionary[@"savedDefaultCharData"]];
+        if (data.length == sizeof(savedDefaultChar_)) {
+            memmove(&savedDefaultChar_, data.bytes, sizeof(savedDefaultChar_));
+        }
+        _preferredCursorPosition = cursor_;
+    }
+    return self;
+}
+
 - (void)dealloc {
     [lines_ release];
     [lineInfos_ release];
@@ -910,7 +951,7 @@ static NSString *const kGridSizeKey = @"Size";
         if (aLine[cursor_.x].code == DWC_RIGHT) {
 #ifdef VERBOSE_STRING
             NSLog(@"Wiping out the right-half DWC at the cursor before writing to screen");
-            ITUpgradedNSAssert(cursor_.x > 0, @"DWC split");  // there should never be the second half of a DWC at x=0
+            ITAssertWithMessage(cursor_.x > 0, @"DWC split");  // there should never be the second half of a DWC at x=0
 #endif
             aLine[cursor_.x].code = 0;
             aLine[cursor_.x].complexChar = NO;
@@ -1671,6 +1712,42 @@ static NSString *const kGridSizeKey = @"Size";
     }
 }
 
+- (VT100GridSize)sizeRespectingRegionConditionally {
+    if (self.cursor.x >= self.leftMargin &&
+        self.cursor.x <= self.rightMargin &&
+        self.cursor.y >= self.topMargin &&
+        self.cursor.y <= self.bottomMargin) {
+        return VT100GridSizeMake(self.rightMargin - self.leftMargin + 1,
+                                 self.bottomMargin - self.topMargin + 1);
+    }
+    return self.size;
+}
+
+- (void)setContinuationMarkOnLine:(int)line to:(unichar)code {
+    screen_char_t *chars = [self screenCharsAtLineNumber:line];
+    assert(chars);
+    chars[size_.width].code = code;
+}
+
+- (void)encode:(id<iTermEncoderAdapter>)encoder {
+    NSArray<NSNumber *> *timestamps = [lineInfos_ mapWithBlock:^id(VT100LineInfo *anObject) {
+        return @(anObject.timestamp);
+    }];
+    NSArray<NSData *> *lines = [[NSArray sequenceWithRange:NSMakeRange(0, size_.height)] mapWithBlock:^id(NSNumber *i) {
+        return [self lineDataAtLineNumber:i.intValue];
+    }];
+    [encoder mergeDictionary:@{
+        @"size": [NSDictionary dictionaryWithGridSize:size_],
+        @"lines": lines,
+        @"timestamps": timestamps,
+        @"cursor": [NSDictionary dictionaryWithGridCoord:cursor_],
+        @"scrollRegionRows": [NSDictionary dictionaryWithGridRange:scrollRegionRows_],
+        @"scrollRegionCols": [NSDictionary dictionaryWithGridRange:scrollRegionCols_],
+        @"useScrollRegionCols": @(useScrollRegionCols_),
+        @"savedDefaultCharData": [NSData dataWithBytes:&savedDefaultChar_ length:sizeof(savedDefaultChar_)]
+    }];
+}
+
 #pragma mark - Private
 
 - (NSMutableArray *)linesWithSize:(VT100GridSize)size {
@@ -1702,6 +1779,7 @@ static NSString *const kGridSizeKey = @"Size";
 
     c.underline = NO;
     c.strikethrough = NO;
+    c.underlineStyle = VT100UnderlineStyleSingle;
     c.urlCode = 0;
     c.image = 0;
 
@@ -1837,6 +1915,7 @@ static NSString *const kGridSizeKey = @"Size";
 // Warning: does not set dirty.
 - (void)setSize:(VT100GridSize)newSize {
     if (newSize.width != size_.width || newSize.height != size_.height) {
+        DLog(@"Grid for %@ resized to %@", self.delegate, VT100GridSizeDescription(newSize));
         size_ = newSize;
         [lines_ release];
         [lineInfos_ release];
@@ -1850,6 +1929,7 @@ static NSString *const kGridSizeKey = @"Size";
                                        size_.height - scrollRegionRows_.location);
         cursor_.x = MIN(cursor_.x, size_.width - 1);
         self.cursorY = MIN(cursor_.y, size_.height - 1);
+        [self.delegate gridDidResize];
     }
 }
 
@@ -1906,6 +1986,19 @@ static NSString *const kGridSizeKey = @"Size";
     return VT100GridCoordMake(cx, cy);
 }
 
+- (screen_char_t)characterAt:(VT100GridCoord)coord {
+    if (coord.y < 0 || coord.y >= self.size.height || coord.x < 0 || coord.x > self.size.width) {
+        ITBetaAssert(NO, @"Asked for %@ in %@", VT100GridCoordDescription(coord), self);
+        screen_char_t defaultChar = { 0 };
+        return defaultChar;
+    } else if (coord.x == self.size.width) {
+        screen_char_t defaultChar = { 0 };
+        return defaultChar;
+    }
+    screen_char_t *line = [self screenCharsAtLineNumber:coord.y];
+    return line[coord.x];
+}
+
 - (NSString *)stringForCharacterAt:(VT100GridCoord)coord {
     screen_char_t *theLine = [self screenCharsAtLineNumber:coord.y];
     if (!theLine) {
@@ -1922,6 +2015,31 @@ static NSString *const kGridSizeKey = @"Size";
     }
 }
 
+- (BOOL)haveDoubleWidthExtensionAt:(VT100GridCoord)coord {
+    screen_char_t sct = [self characterAt:coord];
+    return !sct.complexChar && (sct.code == DWC_RIGHT || sct.code == DWC_SKIP);
+}
+
+- (VT100GridCoord)successorOf:(VT100GridCoord)origin {
+    VT100GridCoord coord = origin;
+    coord.x += 1;
+    BOOL checkedForDWC = NO;
+    if (coord.x < self.size.width && [self haveDoubleWidthExtensionAt:coord]) {
+        coord.x += 1;
+        checkedForDWC = YES;
+    }
+    if (coord.x >= self.size.width) {
+        coord.x = 0;
+        coord.y += 1;
+        if (coord.y >= self.size.height) {
+            return VT100GridCoordMake(-1, -1);
+        }
+        if (!checkedForDWC && [self haveDoubleWidthExtensionAt:coord]) {
+            coord.x++;
+        }
+    }
+    return coord;
+}
 
 #ifdef VERBOSE_STRING
 static void DumpBuf(screen_char_t* p, int n) {
