@@ -32,7 +32,7 @@
 - (void)screenTriggerableChangeDidOccur;
 
 // Called when the screen and terminal's attributes are reset
-- (void)screenDidReset;
+- (void)screenDidResetAllowingContentModification:(BOOL)modifyContent;
 
 // Terminal can change title
 - (BOOL)screenAllowTitleSetting;
@@ -270,6 +270,7 @@
 - (void)screenPushKeyLabels:(NSString *)value;
 - (void)screenPopKeyLabels:(NSString *)value;
 - (void)screenSendModifiersDidChange;
+- (void)screenKeyReportingFlagsDidChange;
 
 - (void)screenTerminalAttemptedPasteboardAccess;
 - (NSString *)screenValueOfVariableNamed:(NSString *)name;
@@ -285,5 +286,6 @@
                          promptIfBig:(BOOL *)promptIfBig;
 - (BOOL)screenShouldClearScrollbackBuffer;
 - (VT100GridRange)screenRangeOfVisibleLines;
+- (void)screenDidResize;
 
 @end
