@@ -191,6 +191,9 @@ static NSString *const iTermAPIScriptLauncherScriptDidFailUserNotificationCallba
       withVirtualEnv:(NSString *)virtualenv
         setupCfgPath:(NSString *)setupCfgPath
   explicitUserAction:(BOOL)explicitUserAction {
+    if (![[NSFileManager defaultManager] homeDirectoryDotDir]) {
+        return;
+    }
     if (virtualenv != nil) {
         // This is a full-environment script. Check if its environment version is supported and
         // offer to upgrade.
@@ -326,7 +329,8 @@ static NSString *const iTermAPIScriptLauncherScriptDidFailUserNotificationCallba
     }
     @catch (NSException *e) {
         [[iTermScriptHistory sharedInstance] addHistoryEntry:entry];
-        [entry addOutput:[NSString stringWithFormat:@"ERROR: Failed to launch: %@", e.reason]];
+        [entry addOutput:[NSString stringWithFormat:@"ERROR: Failed to launch: %@", e.reason]
+              completion:^{}];
         [self didFailToLaunchScript:filename withException:e];
     }
 }
@@ -360,7 +364,7 @@ static NSString *const iTermAPIScriptLauncherScriptDidFailUserNotificationCallba
                                         creatingSymlinkIfNeeded:NO];
     NSString *path = [searchPath stringByAppendingPathComponent:@"versions"];
     NSString *standardPythonVersion = [[iTermPythonRuntimeDownloader bestPythonVersionAt:path] it_twoPartVersionNumber];
-    task.environment = [self environmentFromEnvironment:task.environment
+    task.environment = [self environmentFromEnvironment:[[NSProcessInfo processInfo] environment]
                                                   shell:[iTermOpenDirectory userShell]
                                                  cookie:cookie
                                                     key:key
@@ -371,7 +375,8 @@ static NSString *const iTermAPIScriptLauncherScriptDidFailUserNotificationCallba
     [task setStandardOutput:pipe];
     [task setStandardError:pipe];
 
-    [entry addOutput:[NSString stringWithFormat:@"%@ %@\n", task.launchPath, [task.arguments componentsJoinedByString:@" "]]];
+    [entry addOutput:[NSString stringWithFormat:@"%@ %@\n", task.launchPath, [task.arguments componentsJoinedByString:@" "]]
+          completion:^{}];
     [task launch];   // This can throw
     entry.pids = @[ @(task.processIdentifier) ];
     [self waitForTask:task readFromPipe:pipe historyEntry:entry];
@@ -392,7 +397,7 @@ static NSString *const iTermAPIScriptLauncherScriptDidFailUserNotificationCallba
         environment[@"SHELL"] = shell;
     }
     environment[@"PYTHONIOENCODING"] = @"utf-8";
-    
+
     // OpenSSL bakes in the directory where you compiled it so it can find root certs.
     // That works great if you happen to be me, but it seems that most people aren't.
     // Luckily it lets you set some environment variables to find cert stores.
@@ -451,7 +456,8 @@ static NSString *const iTermAPIScriptLauncherScriptDidFailUserNotificationCallba
         NSData *inData = [readHandle availableData];
         while (inData.length) {
             dispatch_async(dispatch_get_main_queue(), ^{
-                [entry addOutput:[[NSString alloc] initWithData:inData encoding:NSUTF8StringEncoding]];
+                [entry addOutput:[[NSString alloc] initWithData:inData encoding:NSUTF8StringEncoding]
+                      completion:^{}];
             });
             inData = [readHandle availableData];
         }
@@ -460,9 +466,11 @@ static NSString *const iTermAPIScriptLauncherScriptDidFailUserNotificationCallba
         dispatch_async(dispatch_get_main_queue(), ^{
             if (!task.isRunning && (task.terminationReason == NSTaskTerminationReasonUncaughtSignal || task.terminationStatus != 0)) {
                 if (task.terminationReason == NSTaskTerminationReasonUncaughtSignal) {
-                    [entry addOutput:@"\n** Script was killed by a signal **"];
+                    [entry addOutput:@"\n** Script was killed by a signal **"
+                          completion:^{}];
                 } else {
-                    [entry addOutput:[NSString stringWithFormat:@"\n** Script exited with status %@ **", @(task.terminationStatus)]];
+                    [entry addOutput:[NSString stringWithFormat:@"\n** Script exited with status %@ **", @(task.terminationStatus)]
+                          completion:^{}];
                 }
                 if (!entry.terminatedByUser) {
                     NSString *message = [NSString stringWithFormat:@"“%@” ended unexpectedly.", entry.name];
