@@ -41,9 +41,11 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 + (BOOL)aggressiveFocusFollowsMouse;
 + (BOOL)alertsIndicateShortcuts;
 + (BOOL)allowDragOfTabIntoNewWindow;
++ (BOOL)allowIdempotentTriggers;
 + (BOOL)allowInteractiveSwipeBetweenTabs;
 + (BOOL)allowTabbarInTitlebarAccessoryBigSur;
 + (BOOL)alternateMouseScroll;
++ (BOOL)alwaysUseStatusBarComposer;
 + (BOOL)animateGraphStatusBarComponents;
 + (void)setAlternateMouseScroll:(BOOL)value;
 + (NSString *)alternateMouseScrollStringForDown;
@@ -117,6 +119,7 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 + (BOOL)excludeBackgroundColorsFromCopiedStyle;
 + (BOOL)experimentalKeyHandling;
 + (double)extraSpaceBeforeCompactTopTabBar;
++ (double)fakeNotchHeight;
 + (NSString *)fallbackLCCType;
 + (BOOL)fastForegroundJobUpdates;
 + (BOOL)fastTrackpad;
@@ -142,9 +145,11 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 + (double)hotkeyTermAnimationDuration;
 + (BOOL)hotkeyWindowsExcludedFromCycling;
 + (BOOL)hotkeyWindowFloatsAboveOtherWindows DEPRECATED_ATTRIBUTE;
++ (double)idempotentTriggerModeRateLimit;
 + (double)idleTimeSeconds;
 + (BOOL)ignoreHardNewlinesInURLs;
 + (BOOL)includePasteHistoryInAdvancedPaste;
++ (BOOL)includeShortcutInWindowsMenu;
 + (BOOL)indicateBellsInDockBadgeLabel;
 + (double)indicatorFlashInitialAlpha;
 + (double)invalidateShadowTimesPerSecond;
@@ -152,7 +157,6 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 + (BOOL)killJobsInServersOnQuit;
 + (BOOL)killSessionsOnLogout;
 + (BOOL)laxNilPolicyInInterpolatedStrings;
-+ (BOOL)loadFromFindPasteboard;
 + (BOOL)logDrawingPerformance;
 + (BOOL)logRestorableStateSize;
 + (BOOL)logTimestampsWithPlainText;
@@ -160,6 +164,7 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 + (int)maxHistoryLinesToRestore;
 + (int)maximumBytesToProvideToServices;
 + (int)maximumBytesToProvideToPythonAPI;
++ (int)maximumNumberOfTriggerCommands;
 + (int)maxSemanticHistoryPrefixOrSuffix;
 + (double)metalRedrawPeriod;
 + (double)metalSlowFrameRate;
@@ -219,6 +224,7 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 + (BOOL)optionIsMetaForSpecialChars;
 + (BOOL)oscColorReport16Bits;
 + (int)pasteHistoryMaxOptions;
++ (BOOL)pastingClearsSelection;
 + (NSString *)pathsToIgnore;
 + (NSString *)pathToFTP;
 + (NSString *)pathToTelnet;
@@ -226,7 +232,9 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 + (BOOL)pinEditSession;
 + (BOOL)pinchToChangeFontSizeDisabled;
 + (double)pointSizeOfTimeStamp;
++ (BOOL)pollForTmuxForegroundJob;
 + (BOOL)preferSpeedToFullLigatureSupport;
++ (NSString *)preferredBaseDir;
 + (const BOOL *)preventEscapeSequenceFromClearingHistory;
 + (BOOL)saveScrollBufferWhenClearing;
 + (void)setPreventEscapeSequenceFromClearingHistory:(const BOOL *)value;
@@ -240,6 +248,7 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 + (BOOL)proportionalScrollWheelReporting;
 + (int)quickPasteBytesPerCall;
 + (double)quickPasteDelayBetweenCalls;
++ (BOOL)recordTimerDebugInfo;
 + (BOOL)remapModifiersWithoutEventTap;
 
 // Remember window positions? If off, lets the OS pick the window position. Smart window placement takes precedence over this.
@@ -253,6 +262,7 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 + (BOOL)retinaInlineImages;
 + (BOOL)runJobsInServers;
 + (BOOL)saveToPasteHistoryWhenSecureInputEnabled;
++ (double)scrollWheelAcceleration;
 + (NSString *)searchCommand;
 + (BOOL)selectsTabsOnMouseDown;
 + (BOOL)sensitiveScrollWheel;
@@ -283,6 +293,7 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 // background. If the brightness difference is less than this value then the text color becomes
 // black or white.
 + (double)smartCursorColorFgThreshold;
++ (int)smartSelectionRadius;
 + (BOOL)solidUnderlines;
 + (BOOL)squareWindowCorners;
 + (NSString *)sshSchemePath;
@@ -298,6 +309,7 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 + (BOOL)suppressMultilinePasteWarningWhenPastingOneLineWithTerminalNewline;
 + (BOOL)suppressRestartAnnouncement;
 + (BOOL)swapFindNextPrevious;
++ (BOOL)synchronizeQueryWithFindPasteboard;
 + (void)setSuppressRestartAnnouncement:(BOOL)value;
 + (double)tabAutoShowHoldTime;
 + (double)tabFlashAnimationDuration;
@@ -315,6 +327,7 @@ extern NSString *const iTermAdvancedSettingsDidChange;
 + (const BOOL *)tmuxWindowsShouldCloseAfterDetach;
 + (void)setTmuxWindowsShouldCloseAfterDetach:(const BOOL *)value;
 + (BOOL)tolerateUnrecognizedTmuxCommands;
++ (double)toolbeltFontSize;
 + (BOOL)trackingRunloopForLiveResize;
 + (BOOL)traditionalVisualBell;
 + (NSString *)trailingPunctuationMarks;
