@@ -16,6 +16,8 @@
 @property (atomic) BOOL terminateAfterLaunch;
 @end
 
+static NSString *const iTermCommandRunnerErrorDomain = @"com.iterm2.command-runner";
+
 @implementation iTermCommandRunner {
     NSTask *_task;
     NSPipe *_pipe;
@@ -28,13 +30,34 @@
 + (void)unzipURL:(NSURL *)zipURL
    withArguments:(NSArray<NSString *> *)arguments
      destination:(NSString *)destination
-      completion:(void (^)(BOOL))completion {
+      completion:(void (^)(NSError *))completion {
     NSArray<NSString *> *fullArgs = [arguments arrayByAddingObject:zipURL.path];
     iTermCommandRunner *runner = [[self alloc] initWithCommand:@"/usr/bin/unzip"
                                                  withArguments:fullArgs
                                                           path:destination];
+    NSMutableString *errorText = [NSMutableString string];
+    runner.outputHandler = ^(NSData *data, void (^handled)(void)) {
+        NSString *string = [[NSString alloc] initWithData:data encoding:NSUTF8StringEncoding];
+        if (string) {
+            [errorText appendString:string];
+        } else {
+            [errorText appendString:@"\n[non-UTF-8 output]\n"];
+        }
+        static NSInteger maxLength = 1024 * 1024;
+        if (errorText.length > maxLength) {
+            [errorText replaceCharactersInRange:NSMakeRange(0, errorText.length - maxLength)
+                                     withString:@""];
+        }
+        handled();
+    };
     runner.completion = ^(int status) {
-        completion(status == 0);
+        if (!status) {
+            completion(nil);
+            return;
+        }
+        completion([NSError errorWithDomain:iTermCommandRunnerErrorDomain
+                                       code:1
+                                   userInfo:@{ NSLocalizedDescriptionKey: errorText }]);
     };
     [runner run];
 }
@@ -55,16 +78,15 @@
     runner.completion = ^(int status) {
         completion(status == 0);
     };
-    runner.outputHandler = ^(NSData *data) {
+    runner.outputHandler = ^(NSData *data, void (^completion)(void)) {
         DLog(@"%@", [[NSString alloc] initWithData:data encoding:NSUTF8StringEncoding]);
+        completion();
     };
     DLog(@"Running %@ %@", runner.command, [runner.arguments componentsJoinedByString:@" "]);
     [runner run];
 }
 
-- (instancetype)initWithCommand:(NSString *)command
-                  withArguments:(NSArray<NSString *> *)arguments
-                           path:(NSString *)currentDirectoryPath {
+- (instancetype)init {
     self = [super init];
     if (self) {
         _task = [[NSTask alloc] init];
@@ -73,7 +95,15 @@
         _readingQueue = dispatch_queue_create("com.iterm2.crun-reading", DISPATCH_QUEUE_SERIAL);
         _writingQueue = dispatch_queue_create("com.iterm2.crun-writing", DISPATCH_QUEUE_SERIAL);
         _waitingQueue = dispatch_queue_create("com.iterm2.crun-waiting", DISPATCH_QUEUE_SERIAL);
-        assert(command);
+    }
+    return self;
+}
+
+- (instancetype)initWithCommand:(NSString *)command
+                  withArguments:(NSArray<NSString *> *)arguments
+                           path:(NSString *)currentDirectoryPath {
+    self = [self init];
+    if (self) {
         self.command = command;
         self.arguments = arguments;
         self.currentDirectoryPath = currentDirectoryPath;
@@ -200,7 +230,12 @@
     while (inData.length) {
         @autoreleasepool {
             DLog(@"runCommand: Read %@", inData);
-            [self didReadData:inData];
+            dispatch_group_t group = dispatch_group_create();
+            dispatch_group_enter(group);
+            [self didReadData:inData completion:^{
+                dispatch_group_leave(group);
+            }];
+            dispatch_group_wait(group, DISPATCH_TIME_FOREVER);
             if (!self.outputHandler) {
                 DLog(@"%@: %@", [task.arguments componentsJoinedByString:@" "],
                      [[NSString alloc] initWithData:inData encoding:NSUTF8StringEncoding]);
@@ -244,12 +279,13 @@
     });
 }
 
-- (void)didReadData:(NSData *)inData {
+- (void)didReadData:(NSData *)inData completion:(void (^)(void))completion {
     if (!self.outputHandler) {
+        completion();
         return;
     }
     dispatch_async(dispatch_get_main_queue(), ^{
-        self.outputHandler(inData);
+        self.outputHandler(inData, completion);
     });
 }
 
@@ -259,11 +295,15 @@
     NSMutableData *_output;
 }
 
-- (void)didReadData:(NSData *)inData {
+- (void)didReadData:(NSData *)inData completion:(void (^)(void))completion {
     dispatch_async(dispatch_get_main_queue(), ^{
         [self saveData:inData];
+        if (!self.outputHandler) {
+            completion();
+            return;
+        }
+        self.outputHandler(inData, completion);
     });
-    [super didReadData:inData];
 }
 
 - (void)saveData:(NSData *)inData {
