@@ -321,7 +321,7 @@ static iTermController *gSharedInstance;
 - (void)noAction:(id)sender {
 }
 
-- (void)newSessionWithSameProfile:(id)sender {
+- (void)newSessionWithSameProfile:(id)sender newWindow:(BOOL)newWindow {
     Profile *bookmark = nil;
     if (_frontTerminalWindowController) {
         bookmark = [[_frontTerminalWindowController currentSession] profile];
@@ -332,9 +332,10 @@ static iTermController *gSharedInstance;
         NSString *guid = [ProfileModel freshGuid];
         bookmark = [bookmark dictionaryBySettingObject:guid forKey:KEY_GUID];
     }
+    PseudoTerminal *windowController = (newWindow) ? nil : _frontTerminalWindowController;
     [iTermSessionLauncher launchBookmark:bookmark
-                              inTerminal:_frontTerminalWindowController
-                      respectTabbingMode:NO
+                              inTerminal:windowController
+                      respectTabbingMode:newWindow
                               completion:^(PTYSession *session) {
         if (divorced) {
             [session divorceAddressBookEntryFromPreferences];
@@ -361,7 +362,7 @@ static iTermController *gSharedInstance;
 }
 
 - (NSArray<PseudoTerminal *> *)terminalsSortedByNumber {
-    return [_terminalWindows sortedArrayUsingComparator:^NSComparisonResult(id obj1, id obj2) {
+    return [_terminalWindows sortedArrayUsingComparator:^NSComparisonResult(PseudoTerminal *obj1, PseudoTerminal *obj2) {
         return [@([obj1 number]) compare:@([obj2 number])];
     }];
 }
@@ -1043,7 +1044,9 @@ replaceInitialDirectoryForSessionWithGUID:(NSString *)guid
     if ([iTermProfilePreferences boolForKey:KEY_HIDE_AFTER_OPENING inProfile:profile]) {
         [term hideAfterOpening];
     }
-    if (term.windowType != WINDOW_TYPE_LION_FULL_SCREEN) {
+    if (term.windowType == WINDOW_TYPE_LION_FULL_SCREEN) {
+        [term delayedEnterFullscreen];
+    } else {
         iTermProfileHotKey *profileHotKey =
         [[iTermHotKeyController sharedInstance] didCreateWindowController:term
                                                               withProfile:profile];
