@@ -506,7 +506,7 @@ static unsigned long long MakeUniqueID(void) {
 
 // Called on job manager's queue via [self launchChildWithExecutablePath:…]
 - (iTermMultiServerClientOriginatedMessage)copyLaunchRequest:(iTermMultiServerClientOriginatedMessage)original {
-    assert(original.type == iTermMultiServerRPCTypeLaunch);
+    ITAssertWithMessage(original.type == iTermMultiServerRPCTypeLaunch, @"Type is %@", @(original.type));
 
     // Encode and decode the message so we can have our own copy of it.
     iTermClientServerProtocolMessage temp;
@@ -514,13 +514,13 @@ static unsigned long long MakeUniqueID(void) {
 
     {
         const int status = iTermMultiServerProtocolEncodeMessageFromClient(&original, &temp);
-        assert(status == 0);
+        ITAssertWithMessage(status == 0, @"On encode: status is %@", @(status));
     }
 
     iTermMultiServerClientOriginatedMessage messageCopy;
     {
         const int status = iTermMultiServerProtocolParseMessageFromClient(&temp, &messageCopy);
-        assert(status == 0);
+        ITAssertWithMessage(status == 0, @"On decode: status is %@ for encoded length %@", @(status), @(temp.ioVectors[0].iov_len));
     }
 
     return messageCopy;
@@ -735,10 +735,11 @@ static unsigned long long MakeUniqueID(void) {
         static iTermRateLimitedUpdate *rateLimit;
         static dispatch_once_t onceToken;
         dispatch_once(&onceToken, ^{
-            rateLimit = [[iTermRateLimitedUpdate alloc] init];
-            rateLimit.minimumInterval = 2;
+            rateLimit = [[iTermRateLimitedUpdate alloc] initWithName:@"Multi client error"
+                                                     minimumInterval:2];
         });
         [rateLimit performRateLimitedBlock:^{
+            DLog(@"Called");
             NSAlert *alert = [[NSAlert alloc] init];
             alert.messageText = @"Problem Starting iTerm2 Daemon";
             alert.informativeText = message;
@@ -747,6 +748,40 @@ static unsigned long long MakeUniqueID(void) {
     });
 }
 
+- (NSString *)pathToServerInBundle {
+    return [[NSBundle bundleForClass:self.class] pathForAuxiliaryExecutable:@"iTermServer"];
+}
+
+- (BOOL)shouldCopyServerTo:(NSString *)desiredPath {
+    DLog(@"%@", desiredPath);
+    NSFileManager *fileManager = [NSFileManager defaultManager];
+    if (![fileManager fileExistsAtPath:desiredPath]) {
+        DLog(@"File doesn't exist");
+        return YES;
+    }
+
+    NSError *error = nil;
+    NSDictionary<NSFileAttributeKey, id> *attributes = [fileManager attributesOfItemAtPath:desiredPath error:&error];
+    if (!attributes) {
+        DLog(@"%@", error);
+        return YES;
+    }
+
+    const long long existingFileSize = [attributes fileSize];
+
+    NSString *pathToServerInBundle = [self pathToServerInBundle];
+    attributes = [fileManager attributesOfItemAtPath:pathToServerInBundle error:&error];
+    if (!attributes) {
+        DLog(@"%@", error);
+        return YES;
+    }
+
+    const long long bundleFileSize = [attributes fileSize];
+    DLog(@"Existing size=%@ bundle size=%@", @(existingFileSize), @(bundleFileSize));
+
+    return existingFileSize != bundleFileSize;
+}
+
 // Copy iTermServer to a safe location where Autoupdate won't delete it. See issue 9022 for
 // wild speculation on why this is important.
 - (NSString *)serverPathCopyingIfNeeded {
@@ -760,12 +795,14 @@ static unsigned long long MakeUniqueID(void) {
     NSFileManager *fileManager = [NSFileManager defaultManager];
 
     // Does the server already exist where we need it to be?
-    if (![fileManager fileExistsAtPath:desiredPath]) {
-        NSString *sourcePath = [[NSBundle bundleForClass:self.class] pathForAuxiliaryExecutable:@"iTermServer"];
+    if ([self shouldCopyServerTo:desiredPath]) {
+        [fileManager removeItemAtPath:desiredPath error:nil];
+        
+        NSString *sourcePath = [self pathToServerInBundle];
         NSError *error = nil;
-        [[NSFileManager defaultManager] copyItemAtPath:sourcePath
-                                                toPath:desiredPath
-                                                 error:&error];
+        [fileManager copyItemAtPath:sourcePath
+                             toPath:desiredPath
+                              error:&error];
         if (error) {
             [self showError:error
                     message:[NSString stringWithFormat:@"Could not copy %@ to %@: %@", sourcePath, desiredPath, error.localizedDescription]
