@@ -7,13 +7,13 @@
 
 #import <Cocoa/Cocoa.h>
 #import "ITAddressBookMgr.h"
+#import "iTermSharedImageStore.h"
 
 NS_ASSUME_NONNULL_BEGIN
 
-NS_CLASS_AVAILABLE_MAC(10_14)
 @interface iTermImageView : NSView
 
-@property (nonatomic, strong) NSImage *image;
+@property (nonatomic, strong) iTermImageWrapper *image;
 @property (nonatomic) iTermBackgroundImageMode contentMode;
 @property (nonatomic, strong) NSColor *backgroundColor;
 @property (nonatomic) CGFloat blend;
