@@ -71,9 +71,6 @@ static NSString *const iTermPasswordManagerAccountNameUserNameSeparator = @"\u20
 
 @end
 
-@interface iTermPasswordManagerPanel : NSPanel
-@end
-
 @implementation iTermPasswordManagerPanel
 
 - (NSTimeInterval)animationResizeTime:(NSRect)newFrame {
@@ -341,12 +338,13 @@ static NSString *const iTermPasswordManagerAccountNameUserNameSeparator = @"\u20
 }
 
 - (void)orderOutOrEndSheet {
+    [self sendWillClose];
     if (self.window.isSheet) {
         [self.window.sheetParent endSheet:self.window];
     } else {
         [[self window] orderOut:nil];
     }
-    [self sendWillClose];
+    [self sendDidClose];
 }
 
 - (void)doubleClickOnTableView:(id)sender {
@@ -379,6 +377,9 @@ static NSString *const iTermPasswordManagerAccountNameUserNameSeparator = @"\u20
         if (selectedRow < 0 || selectedRow >= _entries.count) {
             return;
         }
+        if (![self shouldRemoveSelection]) {
+            return;
+        }
         [_tableView reloadData];
         [[self keychain] deletePasswordForService:kServiceName account:_entries[selectedRow].combinedAccountNameUserName];
         [self reloadAccounts];
@@ -386,6 +387,14 @@ static NSString *const iTermPasswordManagerAccountNameUserNameSeparator = @"\u20
     }
 }
 
+- (BOOL)shouldRemoveSelection {
+    NSAlert *alert = [[NSAlert alloc] init];
+    alert.messageText = @"Are you sure you want to delete this password?";
+    [alert addButtonWithTitle:@"OK"];
+    [alert addButtonWithTitle:@"Cancel"];
+    return [alert runSheetModalForWindow:self.window] == NSAlertFirstButtonReturn;
+}
+
 - (IBAction)edit:(id)sender {
     const NSInteger row = _tableView.selectedRow;
     if (row >= 0 && row < _entries.count) {
@@ -440,6 +449,7 @@ static NSString *const iTermPasswordManagerAccountNameUserNameSeparator = @"\u20
 }
 
 - (void)closeOrEndSheet {
+    [self sendWillClose];
     if (self.window.isSheet) {
         DLog(@"Ask parent to end sheet");
         [self.window.sheetParent endSheet:self.window];
@@ -447,7 +457,7 @@ static NSString *const iTermPasswordManagerAccountNameUserNameSeparator = @"\u20
         DLog(@"Close window");
         [self.window close];
     }
-    [self sendWillClose];
+    [self sendDidClose];
 }
 
 - (IBAction)editAccountName:(id)sender {
@@ -859,6 +869,13 @@ dataCellForTableColumn:(NSTableColumn *)tableColumn
     _twoFactorCode.stringValue = @"";
     [_tableView reloadData];
     [self sendWillClose];
+    [self sendDidClose];
+}
+
+- (void)sendDidClose {
+    if ([self.delegate respondsToSelector:@selector(iTermPasswordManagerDidClose)]) {
+        [self.delegate iTermPasswordManagerDidClose];
+    }
 }
 
 - (void)sendWillClose {
