@@ -14,6 +14,7 @@
 #import "iTermRestorableStateSQLite.h"
 #import "iTermUserDefaults.h"
 
+static BOOL gShouldIgnoreOpenUntitledFile;
 extern NSString *const iTermApplicationWillTerminate;
 
 @interface NSApplication(Private)
@@ -34,6 +35,26 @@ extern NSString *const iTermApplicationWillTerminate;
     id<iTermRestorableStateRestorer> _restorer;
     iTermRestorableStateDriver *_driver;
     BOOL _ready;
+    NSMutableDictionary<NSString *, void (^)(NSWindow *, NSError *)> *_systemCallbacks;
+    dispatch_group_t _completionGroup;
+}
+
++ (BOOL)shouldIgnoreOpenUntitledFile {
+    return gShouldIgnoreOpenUntitledFile;
+}
+
++ (void)setShouldIgnoreOpenUntitledFile:(BOOL)value {
+    gShouldIgnoreOpenUntitledFile = value;
+}
+
+
++ (instancetype)sharedInstance {
+    static dispatch_once_t onceToken;
+    static id instance;
+    dispatch_once(&onceToken, ^{
+        instance = [[self alloc] init];
+    });
+    return instance;
 }
 
 + (BOOL)stateRestorationEnabled {
@@ -58,6 +79,7 @@ static BOOL gForceSaveState;
 - (instancetype)init {
     self = [super init];
     if (self) {
+        _systemCallbacks = [NSMutableDictionary dictionary];
         dispatch_queue_t queue = dispatch_queue_create("com.iterm2.restorable-state", DISPATCH_QUEUE_SERIAL);
         NSString *appSupport = [[NSFileManager defaultManager] applicationSupportDirectory];
         if (!appSupport) {
@@ -134,12 +156,15 @@ static BOOL gForceSaveState;
 // restoration must be made before state is *saved* not before it is restored. See the comment on
 // shouldRestoreStateOnNextLaunch above.
 - (void)restoreWindowsWithCompletion:(void (^)(void))completion {
+    _completionGroup = dispatch_group_create();
+    dispatch_group_enter(_completionGroup);
     assert([NSThread isMainThread]);
     __weak __typeof(self) weakSelf = self;
-    [_driver restoreWithReady:^{
+    [_driver restoreWithSystemCallbacks:_systemCallbacks
+                                  ready:^{
         [weakSelf.delegate restorableStateDidFinishRequestingRestorations:self];
     }
-                   completion:^{
+                             completion:^{
         DLog(@"Restoration did complete");
         [weakSelf completeInitialization];
         completion();
@@ -151,6 +176,16 @@ static BOOL gForceSaveState;
     [self completeInitialization];
 }
 
+- (void)setSystemRestorationCallback:(void (^)(NSWindow *, NSError *))callback
+                    windowIdentifier:(NSString *)windowIdentifier {
+    if (_ready) {
+        DLog(@"Unexpected window restoration call with id %@", windowIdentifier);
+        callback(nil, nil);
+        return;
+    }
+    _systemCallbacks[windowIdentifier] = [callback copy];
+}
+
 #pragma mark - Private
 
 // NOTE! This is iTermApplicationWillTerminate, not NSApplicationWillTerminateNotification.
@@ -178,15 +213,28 @@ static BOOL gForceSaveState;
     DLog(@"completeInitialization");
     assert([NSThread isMainThread]);
     _ready = YES;
+    dispatch_group_leave(_completionGroup);
     if (![iTermRestorableStateController stateRestorationEnabled]) {
         // Just in case we don't get a chance to erase the state later.
         DLog(@"State restoration is disabled so erase db");
         [_driver eraseSynchronously:NO];
-        return;
-    }
-    if (_driver.needsSave) {
+    } else if (_driver.needsSave) {
         [_driver save];
     }
+    [self invokeRemainingCompletionBlocksAsFailure];
+}
+
+// Run system callbacks that were never married up to windows as failures.
+- (void)invokeRemainingCompletionBlocksAsFailure {
+    NSMutableDictionary<NSString *, void (^)(NSWindow *, NSError *)> *temp = [_systemCallbacks copy];
+    [_systemCallbacks removeAllObjects];
+
+    iTermRestorableStateController.shouldIgnoreOpenUntitledFile = YES;
+    [temp enumerateKeysAndObjectsUsingBlock:^(NSString * _Nonnull windowIdentifier, void (^ _Nonnull completion)(NSWindow *, NSError *), BOOL * _Nonnull stop) {
+        DLog(@"Running system callback with nil for %@", windowIdentifier);
+        completion(nil, nil);
+    }];
+    iTermRestorableStateController.shouldIgnoreOpenUntitledFile = NO;
 }
 
 #pragma mark - iTermRestorableStateRestoring
@@ -196,7 +244,10 @@ static BOOL gForceSaveState;
                              completion:(void (^)(NSWindow *, NSError *))completion {
     [self.delegate restorableStateRestoreWithCoder:coder
                                         identifier:identifier
-                                        completion:completion];
+                                        completion:^(NSWindow * _Nullable window, NSError * _Nullable error) {
+        completion(window, error);
+        [self didRestoreWindow:window];
+    }];
 }
 
 - (void)restorableStateRestoreWithRecord:(nonnull iTermEncoderGraphRecord *)record
@@ -205,13 +256,33 @@ static BOOL gForceSaveState;
                                                            NSError *))completion {
     [self.delegate restorableStateRestoreWithRecord:record
                                          identifier:identifier
-                                         completion:completion];
+                                         completion:^(NSWindow * _Nullable window, NSError * _Nullable error) {
+        NSLog(@"iTermRestorableStateController's completion block calling the completion block for window %@", window);
+        completion(window, error);
+        NSLog(@"iTermRestorableStateController's completion block calling didRestoreWindow:%@", window);
+        __weak __typeof(window) weakWindow = window;
+        dispatch_group_notify(self->_completionGroup, dispatch_get_main_queue(), ^{
+            __strong __typeof(window) strongWindow = weakWindow;
+            if (strongWindow) {
+                [self didRestoreWindow:strongWindow];
+            }
+        });
+        NSLog(@"iTermRestorableStateController's completion block returning");
+    }];
 }
 
 - (void)restorableStateRestoreApplicationStateWithRecord:(nonnull iTermEncoderGraphRecord *)record {
     [self.delegate restorableStateRestoreApplicationStateWithRecord:record];
 }
 
+- (void)didRestoreWindow:(NSWindow *)window {
+    if (![window.delegate conformsToProtocol:@protocol(iTermRestorableWindowController)]) {
+        return;
+    }
+    id<iTermRestorableWindowController> controller = (id<iTermRestorableWindowController>)[window delegate];
+    [controller didFinishRestoringWindow];
+}
+
 #pragma mark - iTermRestorableStateSaving
 
 - (NSArray<NSWindow *> *)restorableStateWindows {
