@@ -154,6 +154,7 @@ NS_CLASS_AVAILABLE_MAC(10_14)
     
     iTermImageView *_backgroundImage NS_AVAILABLE_MAC(10_14);
     NSView *_workaroundView;  // 10.14 only. See issue 8701.
+    iTermLayerBackedSolidColorView *_notchMask NS_AVAILABLE_MAC(12_0);
 }
 
 - (instancetype)initWithFrame:(NSRect)frameRect
@@ -416,6 +417,11 @@ NS_CLASS_AVAILABLE_MAC(10_14)
             _workaroundView = [[SolidColorView alloc] initWithFrame:NSMakeRect(0, 0, 1, 1) color:[NSColor clearColor]];
             [self addSubview:_workaroundView];
         }
+        if (@available(macOS 12.0, *)) {
+            _notchMask = [[iTermLayerBackedSolidColorView alloc] initWithFrame:NSMakeRect(0, 0, 0, 0) color:[NSColor blackColor]];
+            _notchMask.hidden = YES;
+            [self addSubview:_notchMask];
+        }
     }
     return self;
 }
@@ -967,9 +973,7 @@ NS_CLASS_AVAILABLE_MAC(10_14)
 }
 
 - (void)windowDidResize {
-    if (@available(macOS 10.14, *)) {
-        [_windowSizeView setWindowSize:[self.delegate rootTerminalViewCurrentSessionSize]];
-    }
+    [_windowSizeView setWindowSize:[self.delegate rootTerminalViewCurrentSessionSize]];
 }
 
 #pragma mark - Division View
@@ -1064,7 +1068,7 @@ NS_CLASS_AVAILABLE_MAC(10_14)
 
 - (NSRect)toolbeltFrameInWindow:(NSWindow *)thisWindow {
     CGFloat width = floor(_toolbeltWidth);
-    CGFloat top = [self topBorderInset];
+    CGFloat top = [self topBorderInset] + [self notchInset];
     CGFloat bottom = [self bottomBorderInset];
     CGFloat right = [self rightBorderInset];
     NSRect toolbeltFrame = NSMakeRect(self.bounds.size.width - width - right,
@@ -1197,6 +1201,7 @@ NS_CLASS_AVAILABLE_MAC(10_14)
 
         case PSMTab_LeftTab: {
             [self layoutSubviewsWithVisibleLeftTabBarAndInlineToolbelt:showToolbeltInline forWindow:thisWindow];
+            break;
         }
     }
 }
@@ -1234,6 +1239,27 @@ NS_CLASS_AVAILABLE_MAC(10_14)
     return 0;
 }
 
+- (CGFloat)notchInset {
+    if (![_delegate fullScreen]) {
+        return 0;
+    }
+    const BOOL wantToHideMenuBar = [iTermPreferences boolForKey:kPreferenceKeyHideMenuBarInFullscreen];
+    if (!wantToHideMenuBar) {
+        // No need to use a notch mask because the menu bar serves that purpose.
+        return 0;
+    }
+    const CGFloat fakeHeight = [iTermAdvancedSettingsModel fakeNotchHeight];
+    if (fakeHeight > 0) {
+        return fakeHeight;
+    }
+    if (@available(macOS 12, *)) {
+        // self.safeAreaInsets is all 0s on a notch Mac. Why the hell doesn't anything work right?
+        const NSEdgeInsets safeAreaInsets = self.window.screen.safeAreaInsets;
+        return safeAreaInsets.top;
+    }
+    return 0;
+}
+
 - (void)layoutSubviewsWithHiddenTabBarForWindow:(NSWindow *)thisWindow {
     if (!_tabBarControlOnLoan) {
         self.tabBarControl.hidden = YES;
@@ -1246,7 +1272,7 @@ NS_CLASS_AVAILABLE_MAC(10_14)
     [self removeLeftTabBarDragHandle];
     iTermDecorationHeights decorationHeights = {
         .bottom = [self bottomBorderInset],
-        .top = _delegate.divisionViewShouldBeVisible ? kDivisionViewHeight : 0
+        .top = (_delegate.divisionViewShouldBeVisible ? kDivisionViewHeight : 0) + [self notchInset]
     };
     decorationHeights.top += [self topBorderInset];
     if ([self shouldLeaveEmptyAreaAtTop]) {
@@ -1287,7 +1313,7 @@ NS_CLASS_AVAILABLE_MAC(10_14)
     [self removeLeftTabBarDragHandle];
     iTermDecorationHeights decorationHeights = {
         .bottom = [self bottomBorderInset],
-        .top = 0
+        .top = [self notchInset]
     };
     if (!_tabBarControlOnLoan) {
         if (!self.tabBarControl.flashing) {
@@ -1356,7 +1382,7 @@ NS_CLASS_AVAILABLE_MAC(10_14)
     [self setTabBarFrame:tabBarFrame];
     [self setTabBarControlAutoresizingMask:(NSViewWidthSizable | NSViewMaxYMargin)];
     iTermDecorationHeights decorationHeights = {
-        .top = 0,
+        .top = [self notchInset],
         .bottom = tabBarFrame.origin.y
     };
     decorationHeights.top += [self topBorderInset];
@@ -1383,9 +1409,6 @@ NS_CLASS_AVAILABLE_MAC(10_14)
 
 - (NSRect)tabViewFrameByShrinkingForFullScreenTabBar:(NSRect)frame
                                               window:(NSWindow *)thisWindow {
-    if (@available(macOS 10.14, *)) {} else {
-        return frame;
-    }
     if (!thisWindow) {
         return frame;
     }
@@ -1405,6 +1428,10 @@ NS_CLASS_AVAILABLE_MAC(10_14)
                 // Overlaps content
                 return frame;
             }
+            if (!_tabBarControlOnLoan && !self.tabBarControl.flashing) {
+                // Already accounted for this before calling this function.
+                return frame;
+            }
             break;
         case PSMTab_LeftTab:
         case PSMTab_BottomTab:
@@ -1432,7 +1459,7 @@ NS_CLASS_AVAILABLE_MAC(10_14)
     assert(!_tabBarControlOnLoan);
     [self setLeftTabBarWidthFromPreferredWidth];
     iTermDecorationHeights decorationHeights = {
-        .top = 0,
+        .top = [self notchInset],
         .bottom = 0
     };
     decorationHeights.bottom += [self bottomBorderInset];
@@ -1529,6 +1556,8 @@ NS_CLASS_AVAILABLE_MAC(10_14)
 
 - (void)layoutSubviews {
     DLog(@"layoutSubviews");
+    [self.delegate rootTerminalViewWillLayoutSubviews];
+
     if (@available(macOS 10.15, *)) { } else {
         _workaroundView.frame = NSMakeRect(0, self.bounds.size.height - 1, 1, 1);
     }
@@ -1554,6 +1583,11 @@ NS_CLASS_AVAILABLE_MAC(10_14)
     } else {
         [self layoutSubviewsWithVisibleTabBarForWindow:thisWindow inlineToolbelt:showToolbeltInline];
     }
+    if (@available(macOS 12.0, *)) {
+        const CGFloat notchHeight = [self notchInset];
+        _notchMask.hidden = (notchHeight == 0);
+        _notchMask.frame = NSMakeRect(0, NSHeight(self.bounds) - notchHeight, NSWidth(self.bounds), notchHeight);
+    }
 
     if (showToolbeltInline) {
         [self updateToolbeltFrameForWindow:thisWindow];
@@ -1600,7 +1634,7 @@ NS_CLASS_AVAILABLE_MAC(10_14)
 
 - (CGFloat)leftTabBarWidthForPreferredWidth:(CGFloat)preferredWidth contentWidth:(CGFloat)contentWidth {
     const CGFloat minimumWidth = [self minimumTabBarWidth];
-    const CGFloat maximumWidth = MAX(1, contentWidth - [iTermAdvancedSettingsModel terminalMargin] * 2 - 10);
+    const CGFloat maximumWidth = MAX(1, contentWidth - [iTermPreferences intForKey:kPreferenceKeySideMargins] * 2 - 10);
     return MAX(MIN(maximumWidth, preferredWidth), minimumWidth);
 }
 
@@ -1750,7 +1784,13 @@ NS_CLASS_AVAILABLE_MAC(10_14)
     }
     if ([_delegate lionFullScreen] || [_delegate enteringLionFullscreen]) {
         if (isTop) {
-            return [iTermPreferences boolForKey:kPreferenceKeyFlashTabBarInFullscreen];
+            if ([iTermPreferences boolForKey:kPreferenceKeyFlashTabBarInFullscreen]) {
+                return YES;
+            }
+            if (![self tabBarShouldBeVisible] && !_tabBarControlOnLoan) {
+                // Code path taken big Big Sur workaround for issue #9199
+                return YES;
+            }
         } else {
             return NO;
         }
