@@ -25,7 +25,8 @@ BOOL CheckFindMatchAtIndex(NSData *findMatches, int index);
 @protocol iTermTextDrawingHelperDelegate <NSObject>
 
 - (void)drawingHelperDrawBackgroundImageInRect:(NSRect)rect
-                        blendDefaultBackground:(BOOL)blendDefaultBackground;
+                        blendDefaultBackground:(BOOL)blendDefaultBackground
+                                 virtualOffset:(CGFloat)virtualOffset;
 
 - (VT100ScreenMark *)drawingHelperMarkOnLine:(int)line;
 
@@ -60,6 +61,7 @@ BOOL CheckFindMatchAtIndex(NSData *findMatches, int index);
 - (void)drawingHelperDidFindRunOfAnimatedCellsStartingAt:(VT100GridCoord)coord ofLength:(int)length;
 
 - (NSString *)drawingHelperLabelForDropTargetOnLine:(int)line;
+- (NSRect)textDrawingHelperVisibleRect;
 
 @end
 
@@ -155,8 +157,8 @@ BOOL CheckFindMatchAtIndex(NSData *findMatches, int index);
 // Should a box cursor be drawn filled in?
 @property(nonatomic, assign) BOOL shouldDrawFilledInCursor;
 
-// Does bold text render as the bright version of a dim ansi color?
-@property(nonatomic, assign) BOOL useBrightBold;
+// Does bold text render as the bright version of a dim ansi color, and also use specified bold color?
+@property(nonatomic, assign) BOOL useCustomBoldColor;
 
 // Is this the current text view of the "front" terminal window?
 // TODO: This might be the same as textViewIsActiveSession.
@@ -180,7 +182,7 @@ BOOL CheckFindMatchAtIndex(NSData *findMatches, int index);
 // Should the cursor guide be shown?
 @property(nonatomic, assign) BOOL highlightCursorLine;
 
-// Mimimum contrast level, 0-1.
+// Minimum contrast level, 0-1.
 @property(nonatomic, assign) double minimumContrast;
 
 // Should the non-ascii font be used?
@@ -193,7 +195,7 @@ BOOL CheckFindMatchAtIndex(NSData *findMatches, int index);
 @property(nonatomic, assign) VT100GridAbsWindowedRange underlinedRange;
 
 // If set, the last-modified time of each line on the screen is shown on the right side of the display.
-@property(nonatomic, assign) BOOL showTimestamps;
+@property(nonatomic) BOOL shouldShowTimestamps;
 
 // Amount to shift anti-aliased text by horizontally to simulate bold
 @property(nonatomic, assign) CGFloat antiAliasedShift;
@@ -234,6 +236,7 @@ BOOL CheckFindMatchAtIndex(NSData *findMatches, int index);
 @property(nonatomic, assign) BOOL animated;
 
 @property(nonatomic, assign) BOOL isRetina;
+@property(nonatomic, assign) BOOL forceAntialiasingOnRetina;
 
 // Draw mark indicators?
 @property(nonatomic, assign) BOOL drawMarkIndicators;
@@ -283,6 +286,15 @@ BOOL CheckFindMatchAtIndex(NSData *findMatches, int index);
 // symbols (non-alphanumerics) get to use the fastpath.
 @property (nonatomic, readonly) BOOL asciiLigaturesAvailable;
 
+@property (nonatomic, readonly, class) NSColor *successMarkColor;
+@property (nonatomic, readonly, class) NSColor *errorMarkColor;
+@property (nonatomic, readonly, class) NSColor *otherMarkColor;
+@property (nonatomic) BOOL useNativePowerlineGlyphs;
+@property (nonatomic) CGFloat badgeTopMargin;
+@property (nonatomic) CGFloat badgeRightMargin;
+
+@property (nonatomic, readonly) NSColor *blockCursorFillColorRespectingSmartSelection;
+
 // imageSize: size of image to draw
 // destinationRect: rect bounding the region of a scrollview's content view (i.e., very tall view) that's being drawn
 // destinationFrameSize: size of the scrollview's content view
@@ -294,40 +306,50 @@ BOOL CheckFindMatchAtIndex(NSData *findMatches, int index);
                   destinationRect:(NSRect)destinationRect
              destinationFrameSize:(NSSize)destinationFrameSize
                       visibleSize:(NSSize)visibleSize
-                    sourceRectPtr:(NSRect *)sourceRectPtr;
+                    sourceRectPtr:(NSRect *)sourceRectPtr
+                          margins:(NSEdgeInsets)margins;
 
 // Indicates whether the cursor should take its color from the background (if YES) or text color (if NO).
 + (BOOL)cursorUsesBackgroundColorForScreenChar:(screen_char_t)screenChar
                                 wantBackground:(BOOL)wantBackgroundColor
                                   reverseVideo:(BOOL)reverseVideo;
 
++ (NSRect)frameForMarkContainedInRect:(NSRect)container
+                             cellSize:(CGSize)cellSize
+               cellSizeWithoutSpacing:(CGSize)cellSizeWithoutSpacing
+                                scale:(CGFloat)scale;
+
 // Updates self.blinkingFound.
 - (void)drawTextViewContentInRect:(NSRect)rect
                          rectsPtr:(const NSRect *)rectArray
-                        rectCount:(NSInteger)rectCount;
-
-- (NSImage *)imageForCoord:(VT100GridCoord)coord size:(CGSize)size;
+                        rectCount:(NSInteger)rectCount
+                    virtualOffset:(CGFloat)virtualOffset;
 
 // If timestamps are to be shown, call this just before drawing.
 - (void)createTimestampDrawingHelper;
 
 // Draw timestamps.
-- (void)drawTimestamps;
+- (void)drawTimestampsWithVirtualOffset:(CGFloat)virtualOffset;
 
 - (VT100GridCoordRange)coordRangeForRect:(NSRect)rect;
 
-- (CGFloat)yOriginForUnderlineGivenFontXHeight:(CGFloat)xHeight yOffset:(CGFloat)yOffset;
+- (CGFloat)yOriginForUnderlineForFont:(NSFont *)font yOffset:(CGFloat)yOffset cellHeight:(CGFloat)cellHeight;
+- (CGFloat)yOriginForStrikethroughForFont:(NSFont *)font yOffset:(CGFloat)yOffset cellHeight:(CGFloat)cellHeight;
+
 - (CGFloat)underlineThicknessForFont:(NSFont *)font;
+- (CGFloat)strikethroughThicknessForFont:(NSFont *)font;
 - (NSRange)underlinedRangeOnLine:(long long)row;
 
 - (void)updateCachedMetrics;
 
 @end
 
-NS_INLINE BOOL iTermTextDrawingHelperIsCharacterDrawable(screen_char_t *c,
+NS_INLINE BOOL iTermTextDrawingHelperIsCharacterDrawable(const screen_char_t *const c,
+                                                         const screen_char_t *const predecessor,
                                                          BOOL isStringifiable,
                                                          BOOL blinkingItemsVisible,
-                                                         BOOL blinkAllowed) {
+                                                         BOOL blinkAllowed,
+                                                         BOOL preferSpeedToFullLigatureSupport) {
     const unichar code = c->code;
     if (c->image) {
         return YES;
@@ -338,7 +360,16 @@ NS_INLINE BOOL iTermTextDrawingHelperIsCharacterDrawable(screen_char_t *c,
             code == TAB_FILLER ||
             code < ' ') {
             return NO;
-        } else if (code == ' ' && !c->underline) {
+        } else if (preferSpeedToFullLigatureSupport &&
+                   code == ' ' &&
+                   !c->underline &&
+                   !c->strikethrough &&
+                   !c->urlCode) {
+            return NO;
+        }
+    } else if (predecessor && ComplexCharCodeIsSpacingCombiningMark(c->code)) {
+        if (predecessor->complexChar || predecessor->code > 127) {
+            // A spacing combining mark that has a non-ascii predecessor is not visible because the predecessor draws it.
             return NO;
         }
     }
@@ -358,7 +389,7 @@ NS_INLINE BOOL iTermTextDrawingHelperIsCharacterDrawable(screen_char_t *c,
 
         }
     } else {
-        // Chatacter hidden because of blinking.
+        // Character hidden because of blinking.
         return NO;
     }
 }
