@@ -15,6 +15,7 @@
 #import "iTermCompetentTableRowView.h"
 
 #import "NSArray+iTerm.h"
+#import "NSFont+iTerm.h"
 #import "NSImage+iTerm.h"
 #import "NSIndexSet+iTerm.h"
 #import "NSStringITerm.h"
@@ -296,24 +297,31 @@ static NSButton *iTermToolSnippetsNewButton(NSString *imageName, NSString *title
 }
 
 - (void)applySelectedSnippets {
+    DLog(@"%@", [NSThread callStackSymbols]);
     for (iTermSnippet *snippet in [self selectedSnippets]) {
+        DLog(@"Create action to send snippet %@", snippet);
         iTermToolWrapper *wrapper = self.toolWrapper;
-        iTermAction *action = [[iTermAction alloc] initWithTitle:@"Send Snippet" action:KEY_ACTION_TEXT parameter:snippet.value];
+        iTermAction *action = [[iTermAction alloc] initWithTitle:@"Send Snippet"
+                                                          action:KEY_ACTION_SEND_SNIPPET
+                                                       parameter:snippet.actionKey
+                                        useCompatibilityEscaping:snippet.useCompatibilityEscaping];
         [wrapper.delegate.delegate toolbeltApplyActionToCurrentSession:action];
     }
 }
 
 - (NSArray<iTermSnippet *> *)selectedSnippets {
+    DLog(@"selected row indexes are %@", _tableView.selectedRowIndexes);
     NSArray<iTermSnippet *> *snippets = [[iTermSnippetsModel sharedInstance] snippets];
+    DLog(@"Snippets are:\n%@", snippets);
     return [[_tableView.selectedRowIndexes it_array] mapWithBlock:^id(NSNumber *indexNumber) {
+        DLog(@"Add snippet at %@", indexNumber);
         return snippets[indexNumber.integerValue];
     }];
 }
 
 - (NSSize)contentSize {
     NSSize size = [_scrollView contentSize];
-    size.height = [[_tableView headerView] frame].size.height;
-    size.height += [_tableView numberOfRows] * ([_tableView rowHeight] + [_tableView intercellSpacing].height);
+    size.height = _tableView.intrinsicContentSize.height;
     return size;
 }
 
@@ -374,7 +382,7 @@ static NSButton *iTermToolSnippetsNewButton(NSString *imageName, NSString *title
 
         NSString *value = [self valueStringForRow:row];
         result.stringValue = value;
-        result.font = [NSFont fontWithName:@"Menlo" size:11];
+        result.font = [NSFont it_toolbeltFont];
         result.lineBreakMode = NSLineBreakByTruncatingTail;
         return result;
     }
@@ -411,7 +419,7 @@ writeRowsWithIndexes:(NSIndexSet *)rowIndexes
                    owner:self];
 
     NSArray<NSNumber *> *plist = [rowIndexes.it_array mapWithBlock:^id(NSNumber *anObject) {
-        return @(_snippets[anObject.integerValue].identifier);
+        return _snippets[anObject.integerValue].guid;
     }];
     [pboard setPropertyList:plist
                     forType:iTermToolSnippetsPasteboardType];
@@ -449,9 +457,9 @@ writeRowsWithIndexes:(NSIndexSet *)rowIndexes
     dropOperation:(NSTableViewDropOperation)operation {
     [self pushUndo];
     NSPasteboard *pboard = [info draggingPasteboard];
-    NSArray<NSNumber *> *identifiers = [pboard propertyListForType:iTermToolSnippetsPasteboardType];
-    [[iTermSnippetsModel sharedInstance] moveSnippetsWithIdentifiers:identifiers
-                                                             toIndex:row];
+    NSArray<NSString *> *guids = [pboard propertyListForType:iTermToolSnippetsPasteboardType];
+    [[iTermSnippetsModel sharedInstance] moveSnippetsWithGUIDs:guids
+                                                       toIndex:row];
     return YES;
 }
 
@@ -487,7 +495,10 @@ writeRowsWithIndexes:(NSIndexSet *)rowIndexes
         return NO;
     }
     NSString *title = [self titleFromString:string];
-    iTermSnippet *snippet = [[iTermSnippet alloc] initWithTitle:title value:string];
+    iTermSnippet *snippet = [[iTermSnippet alloc] initWithTitle:title
+                                                          value:[string stringByEscapingControlCharactersAndBackslash]
+                                                           guid:[[NSUUID UUID] UUIDString]
+                                       useCompatibilityEscaping:NO];
     [[iTermSnippetsModel sharedInstance] addSnippet:snippet];
     return YES;
 }
