@@ -21,7 +21,7 @@ extern NSString *const iTermVariableKeyTabTitleOverride;
 extern NSString *const iTermVariableKeyTabTitleOverrideFormat;
 extern NSString *const iTermVariableKeyTabCurrentSession;
 extern NSString *const iTermVariableKeyTabID;
-extern NSString *const iTermVariableKeyTabTmuxWindowTitle;
+extern NSString *const iTermVariableKeyTabTmuxWindowTitle;  // #{T:set-titles-string} for a particular tmux window
 extern NSString *const iTermVariableKeyTabTmuxWindowName;
 extern NSString *const iTermVariableKeyTabWindow;
 extern NSString *const iTermVariableKeyTabTitle;
@@ -52,21 +52,24 @@ extern NSString *const iTermVariableKeySessionJob;  // job name, not affected by
 extern NSString *const iTermVariableKeySessionProcessTitle;  // process title, affected by modifying argv[0]. see issue 4214 for details.
 extern NSString *const iTermVariableKeySessionCommandLine;  // Current foreground job with arguments
 extern NSString *const iTermVariableKeySessionPresentationName;  // What's shown in the session title view
-extern NSString *const iTermVariableKeySessionTmuxPaneTitle;  // Evaluation of 'show-options -v -g set-titles-string'
+extern NSString *const iTermVariableKeySessionTmuxPaneTitle;  // #{pane_title} for a particular session
 extern NSString *const iTermVariableKeySessionTmuxRole;  // Unset (normal session), "gateway" (where you ran tmux -CC), or "client".
 extern NSString *const iTermVariableKeySessionTmuxClientName;  // Set on tmux gateways. Gives a name for the tmux session.
-extern NSString *const iTermVariableKeySessionTmuxWindowPane;  // NSNumber. Window pane number. Set if the session is a tmux session;
+extern NSString *const iTermVariableKeySessionTmuxWindowPane;  // NSNumber. Window pane number #{pane_id}. Set if the session is a tmux session;
+extern NSString *const iTermVariableKeySessionTmuxWindowPaneIndex;  // NSString. #{pane_index} for a particular session. Only available on tmux 3.2+.
 extern NSString *const iTermVariableKeySessionJobPid;  // NSNumber. Process id of foreground job.
 extern NSString *const iTermVariableKeySessionChildPid;  // NSNumber. Process id of child of session task.
 extern NSString *const iTermVariableKeySessionTmuxStatusLeft;  // String. Only set when in tmux integration mode.
 extern NSString *const iTermVariableKeySessionTmuxStatusRight;  // String. Only set when in tmux integration mode.
 extern NSString *const iTermVariableKeySessionMouseReportingMode;  // NSNumber (MouseMode)
+extern NSString *const iTermVariableKeySessionShowingAlternateScreen;  // NSBoolean
 extern NSString *const iTermVariableKeySessionBadge;  // NSString. Evaluated badge swifty string.
 extern NSString *const iTermVariableKeySessionTab;  // NString. Containing tab.
 extern NSString *const iTermVariableKeySessionSelection;  // NSString. Containing selected text.
 extern NSString *const iTermVariableKeySessionSelectionLength;  // NSNumber. Contains length of selected text.
 extern NSString *const iTermVariableKeySessionParent;  // Session that was active when this one was created, if any.
 extern NSString *const iTermVariableKeySessionBellCount;  // NSNumber. Number of times the bell has tried to ring.
+extern NSString *const iTermVariableKeySessionLogFilename;  // NSString. Path to log file. Unset if not logging.
 
 extern NSString *const iTermVariableKeyWindowTitleOverrideFormat;
 extern NSString *const iTermVariableKeyWindowCurrentTab;
